/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 09833
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1990
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 09833-0001-statasetup.do)
 |
 **************************************************************************/

set mem 30m  /* Allocating 30 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.\n
**********************************************************/


label data "National Household Survey on Drug Abuse, 1990, Dataset 0001"

#delimit ;
label define CIGTRY    185 "BAD DATA Logically assigned"
                       191 "NEVER USED CIGARETTES" 194 "DONT KNOW"
                       195 "BAD DATA" 196 "MULTIPLE RESPONSE"
                       198 "BLANK (NO ANSWER)" ;
label define CIG5PK    1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       81 "NEVER USED CIGARETTES Logically assigned"
                       91 "NEVER USED CIGARETTES" 98 "BLANK (NO ANSWER)" ;
label define CIGAGE    181 "NEVER USED CIGARETTES Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED CIGARETTES" 193 "NEVER SMOKED DAILY"
                       194 "DONT KNOW" 198 "BLANK (NO ANSWER)" ;
label define CIGYRS    181 "NEVER USED CIGARETTES Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED CIGARETTES" 194 "DONT KNOW"
                       198 "BLANK (NO ANSWER)"
                       199 "LEGITIMATE SKIP (CIGAGE = 193)" ;
label define PACKS     1 "One to five cigarettes a day"
                       2 "About 1/2 pack a day (6-15 cigarettes)"
                       3 "About a pack a day (16-25 cigarettes)"
                       4 "About 1 1/2 packs a day (26-35 cigarette"
                       5 "About 2 packs or more a day(over 35 cigarettes)"
                       91 "NEVER USED CIGARETTES" 98 "BLANK"
                       99 "LEGITIMATE SKIP (CIGAGE = 193)" ;
label define CIGREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months"
                       3 "6 or more months ago but less than 1 year"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED CIGARETTES" 98 "BLANK" ;
label define AVCIG     1 "Less than one cigarette a day"
                       2 "One to five cigarettes a day"
                       3 "About 1/2 pack a day (6-15 cigarettes)"
                       4 "About a pack a day (16-25 cigarettes)"
                       5 "About 1 1/2 packs a day (26-35 cigarettes)"
                       6 "About 2 packs or more a day (over 35 cigarettes)"
                       81 "NEVER USED CIGARETTES Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED CIGARETTES" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define CIGTIME   9981 "NEVER USED CIGARETTES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED CIGARETTES" 9994 "DONT KNOW"
                       9995 "BAD DATA" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define SNUFREC   1 "Within the past month(30 days)"
                       2 "More than 1 month ago but less than 6 months"
                       3 "6 or more months ago but less than 1 year"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       91 "NEVER USED SMOKELESS TOBACCO" 98 "BLANK" ;
label define OTHTOB    1 "Daily" 2 "Almost daily (3-6 days a week)"
                       3 "1 or 2 days a week"
                       4 "Several times a month (25-51 days a year)"
                       5 "1 or 2 times a month (12-24 days a year)"
                       6 "Every other month or so (6-11 days a year)"
                       7 "3-5 days this past year"
                       8 "1 or 2 days this past year"
                       81 "NEVER USED SMOKELESS TOBACCO Log. assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SMOKELESS TOBACCO IN LIFETIME"
                       93 "DID NOT USE SMOKELESS TOBACCO IN THE PAST YEAR"
                       98 "BLANK (NO ANSWER)" ;
label define ALCTRY    181 "NEVER USED ALCOHOL Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED ALCOHOL" 192 "ILLEGIBLE"
                       194 "DONT KNOW" 195 "BAD DATA" 197 "REFUSED"
                       198 "BLANK (NO ANSWER)" ;
label define ALCREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months"
                       3 "6 or more months ago but less than 1 year"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED ALCOHOL" ;
label define ALCAGE    181 "NEVER USED ALCOHOL Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED ALCOHOL" 192 "ILLEGIBLE"
                       193 "NEVER USED ALCOHOL MONTHLY OR MORE OFTEN"
                       194 "DONT KNOW" 195 "BAD DATA" 196 "MULTIPLE RESPONSE"
                       197 "REFUSED" 198 "BLANK (NO ANSWER)" ;
label define ALCDAYS   81 "NEVER USED ALCOHOL Logically assigned"
                       85 "DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned"
                       91 "NEVER USED ALCOHOL" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NODR30A   81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DR5DAY    81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" 94 "DONT KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MODR30A   81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MODR30DY  81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" 94 "DONT KNOW" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ALCPAT    1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25-51 days)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTH"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DRUNKYR   1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25-51 days)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       9 "Never got very high or drunk in past 12 months"
                       81 "NEVER USE ALCOHOL Logically assigned"
                       83 "DID NOT USED ALCOHOL PAST 12 MOS."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTHS"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ALCSED    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCTRAN   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCSTM    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCANAL   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCMJ     1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCINH    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCCOC    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCHAL    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCOPT    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCNONE   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned"
                       85 "MULTIPLE RESPONSE" 91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS" ;
label define ALCPREF   1 "Beer" 2 "Wine" 3 "Liquor" 4 "It varies"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       85 "MULTIPLE RESPONSE Logically assigned"
                       91 "NEVER USED ALCOHOL" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define NOSEDAT   1 "Response circled" 2 "Response not circled"
                       98 "BLANK (NO ANSWER)" ;
label define BUTISOL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define BUTICAPS  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define AMYTAL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define MEBARAL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define PLACIDYL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define DORIDEN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define NOLUDAR   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define NEMBUTAL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SECONAL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define TUINAL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define DALMANE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define RESTORIL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define HALCION   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define AMOBARB   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define PHENOBAR  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define METHAQ    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define CHHYD     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define PENTOB    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SECOB     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDNEWA   110 "Tuinal"
                       116 "Methaqualone (including Sopor, Quaalude)"
                       120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       121 "USED SEDATIVE, DONT KNOW NAME" 122 "Sleep Aid"
                       125 "Qulande" 126 "Somenx" 137 "7-14" 201 "Valium"
                       226 "Stelazenorgin" 305 "Biphetamine" 331 "Whites"
                       332 "Ephedrine" 339 "Amphetamines (speed)"
                       360 "Rainbow (speed)" 406 "Percodan"
                       409 "Tylenol with Codeine" 415 "Codeine"
                       420 "OTHER Analgesic,NOT SPECIFIED" 422 "Motrin"
                       423 "Percocet" 425 "Advil" 430 "Asprin" 435 "Tylenol"
                       603 "Mescaline" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "Marijuana" 991 "NEVER USED SEDATIVES"
                       998 "BLANK (NO ANSWER)" ;
label define SEDNEWB   116 "Methaqualone (including Sopor, Quaalude)"
                       202 "Librium" 435 "Tylenol" 436 "Buffrin"
                       438 "Napersin,Naproseyn" 991 "NEVER USED SEDATIVES"
                       998 "BLANK (NO ANSWER)" ;
label define SEDNEWC   201 "Valium" 991 "NEVER USED SEDATIVES"
                       998 "BLANK (NO ANSWER)" ;
label define SEDNOSP   1 "Response circled" 2 "Response not circled"
                       3 "Sedative use LOGICALLY IMPUTED"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDDKNAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDAGE    181 "NEVER USED SEDATIVES Logically assigned"
                       191 "NEVER USED SEDATIVES" 192 "ILLEGIBLE"
                       195 "BAD DATA" 198 "BLANK (NO ANSWER)" ;
label define SEDTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months"
                       3 "6 or more months ago but less than 1 year"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDYRFRQ  1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 days)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 to 2 days in the past 12 months"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       83 "DID NOT USE SEDATIVE PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE ANY SEDATIVE IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define AS3READ   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself" 98 "BLANK" ;
label define NOTRANQ   1 "Response circled" 2 "Response not circled"
                       98 "BLANK (NO ANSWER)" ;
label define VALIUM    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define LIBRIUM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define LIMBTROL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define MENRIUM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define SERAX     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRANXENE  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define ATIVAN    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define CENTRAX   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define XANAX     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define PAXIPAM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define BUSPAR    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define MILTOWN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define EQUANIL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define DEPROL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define VISTAR    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define ATARAX    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define DURRAX    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define DIAZEPAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define SKLY      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define MEPROB    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRNEWA    111 "Dalmane"
                       116 "Methaqualone (including Sopor, Quaalude)"
                       137 "7-14" 201 "Valium"
                       221 "OTHER Tranquilizer, DONT KNOW NAME" 223 "Robaxin"
                       226 "Stelazenorgin" 228 "Amitriptyline" 231 "M.S"
                       425 "Advil" 434 "Vicodin" 435 "Tylenol"
                       801 "OTHER Drugs, NOT SPECIFIED"
                       991 "NEVER USED TRANQUILIZERS" 998 "BLANK (NO ANSWER)" ;
label define TRNEWB    230 "Compazine" 991 "NEVER USED TRANQUILIZERS"
                       998 "BLANK (NO ANSWER)" ;
label define TRNEWC    227 "Thorazine" 991 "NEVER USED TRANQUILIZERS"
                       998 "BLANK (NO ANSWER)" ;
label define TRNOSP    1 "Response circled" 2 "Response not circled"
                       3 "Tranquilizer use LOGICALLY IMPUTED"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRDKNAM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRANAGE   181 "NEVER USED TRANQUILIZERS Logically assigned"
                       191 "NEVER USED TRANQUILIZERS" 195 "BAD DATA"
                       198 "BLANK (NO ANSWER)" ;
label define TRANTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRANREC   1 "Within the past month(30 days)"
                       2 "More than 1 month ago but less than 6 months"
                       3 "6 or more months ago but less than 1 year"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRNYRFRQ  1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 days)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 to 2 days in the past 12 months"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       83 "DID NOT USE TRANQUILIZER PAST 12 MOS."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE ANY TRANQUILIZER IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define AS4READ   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself" 98 "BLANK" ;
label define NOSTIMS   1 "Response circled" 2 "Response not circled"
                       98 "BLANK (NO ANSWER)" ;
label define DEXED     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define DEXAMYL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define ESKAT     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define BENZ      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define BIPHET    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define DESOXYN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define TENUATE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define TEPANIL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define DIDREX    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define PLEGINE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define PRELUDIN  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define IONAMIN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define FASTIN    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define PONDIMIN  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define VORANIL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define SANOREX   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define MAZANOR   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define RITALIN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define CYLERT    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define DETAMP    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define METHI     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define METHAMP   1 "Response circled" 2 "Response not circled"
                       3 "Methamphetamine use LOGICALLY IMPUTED"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define OBLA      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STIMNEWA  124 "Yellow jackets" 321 "Methedrine"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant,NOT SPECIFIED, Uppers"
                       325 "USED STIMULANT, DONT KNOW NAME" 326 "White cross"
                       327 "Black Beauty, Black beauties" 328 "Pink hearts"
                       331 "Whites" 332 "Ephedrine"
                       333 "357 Magnum, Magnum 44"
                       334 "Cross tops, Crossroads" 335 "Dexatrim"
                       339 "Amphetamines (speed)" 345 "Black Molly"
                       354 "Vivarin" 356 "Dexies"
                       357 "Heart shaped black pills" 358 "20/20"
                       359 "Criss Cross" 601 "LSD" 614 "MDA"
                       801 "OTHER Drugs, NOT SPECIFIED" 805 "Cocaine, Crack"
                       814 "Caffeine" 991 "NEVER USED STIMULANTS"
                       994 "DONT KNOW" 998 "BLANK (NO ANSWER)" ;
label define STIMNEWB  322 "Methamphetamine (Speed or Crank)"
                       325 "USED STIMULANT DONT KNOW NAME" 326 "White cross"
                       327 "Black Beauty, Black beauties" 328 "Pink hearts"
                       329 "Robins eggs" 332 "Ephedrine"
                       604 "Psilocybin (mushrooms)" 805 "Cocaine, Coke"
                       806 "Crack" 814 "Caffeine" 991 "NEVER USED STIMULANTS"
                       994 "DONT KNOW" 998 "BLANK (NO ANSWER)" ;
label define STIMNEWC  124 "Yellow jackets" 991 "NEVER USED STIMULANTS"
                       994 "DONT KNOW" 998 "BLANK (NO ANSWER)" ;
label define STIMNEWD  324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       991 "NEVER USED STIMULANTS" 994 "DONT KNOW"
                       998 "BLANK (NO ANSWER)" ;
label define STIMNOSP  1 "Response circled" 2 "Response not circled"
                       3 "Stimulant use LOGICALLY IMPUTED"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STMDKNAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STIMAGE   181 "NEVER USED STIMULANTS Logically assigned"
                       191 "NEVER USED STIMULANTS" 195 "BAD DATA"
                       198 "BLANK (NO ANSWER)" ;
label define STIMTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STIMREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months"
                       3 "6 or more months ago but less than 1 year"
                       4 "1 or more years ago but less than 3 years"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STMYRFRQ  1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 days)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 to 2 days in the past 12 months"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       83 "DID NOT USE STIMULANT PAST 12 MOS."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANT IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define STNEEDLE  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STNDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months"
                       3 "6 or more months ago but less than 1 year"
                       4 "1 or more years ago but less than 3 years"
                       5 "3 or more years ago but less than 10 years"
                       6 "10 or more years ago" 91 "NEVER USED STIMULANTS"
                       93 "NEVER USED AMPHETAMINES WITH A NEEDLE"
                       98 "BLANK (NO ANSWER)" ;
label define AS5READ   1 "Wants interviewer to read questions"
                       2 "Wants to do it himself/herself" 98 "BLANK" ;
label define ANALNONE  1 "Response circled" 2 "Response not circled"
                       98 "BLANK (NO ANSWER)" ;
label define DARVON    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define DOLENE    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define SK65A     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define WYGESIC   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define LEVODRO   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define PERCODAN  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define DEMEROL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define DILAUD    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define TYLCOD    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define PHENCOD   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define TALWIN    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define TALWINNX  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define TALACEN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define PROPOXY   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define CODEINE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANILERID  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define MORPHINE  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define METHDON   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define STADOL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANALNEWA  120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       124 "Yellow jackets" 406 "Percodan" 415 "Codeine"
                       418 "Methadone" 420 "OTHER Analgesic, NOT SPECIFIED"
                       421 "USED ANALGESIC, DONT KNOW NAME" 422 "Motrin"
                       423 "Percocet" 426 "Fiornal" 427 "Darvocet"
                       430 "Asprin, Ecotrine" 431 "Tyloxe" 435 "Tylenol"
                       437 "Parafan Forte" 991 "NEVER USED ANALGESICS"
                       998 "BLANK (NO ANSWER)" ;
label define ANALNEWB  702 "Heroin" 991 "NEVER USED ANALGESICS"
                       998 "BLANK (NO ANSWER)" ;
label define ANALNEWC  420 "OTHER Analgesic, DONT KNOW NAME"
                       991 "NEVER USED ANALGESICS" 998 "BLANK (NO ANSWER)" ;
label define ANLNOSP   1 "Response circled" 2 "Response not circled"
                       3 "Analgesic use LOGICALLY IMPUTED"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANLDKNAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANALAGE   181 "NEVER USED ANALGESICS Logically assigned"
                       191 "NEVER USED ANALGESICS" 194 "DONT KNOW"
                       195 "BAD DATA" 198 "BLANK (NO ANSWER)" ;
label define ANALTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANALREC   1 "Within past month (30 days)"
                       2 "More than 1 month ago but less than 6 months"
                       3 "6 or more months ago but less than 1 year"
                       4 "1 or more years ago but less than 3 years"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANLYRFRQ  1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 days)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 to 2 days in the past 12 months"
                       81 "NEVER USED ANALGESICS Logically assigned"
                       83 "DID NOT USE ANALGESIC PAST 12 MOS."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANALGESICS"
                       93 "DID NOT USE ANALGESIC IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define MJOPP     181 "NEVER HAD CHANCE TO TRY MARIJUANA"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER HAD CHANCE TO TRY MARIJUANA"
                       192 "ILLEGIBLE" 194 "DONT KNOW" 197 "REFUSED"
                       198 "BLANK (NO ANSWER)" ;
label define MJAGE     181 "NEVER USED MARIJUANA Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED MARIJUANA" 192 "ILLEGIBLE"
                       194 "DONT KNOW" 195 "BAD DATA" 198 "BLANK (NO ANSWER)" ;
label define MJTOT     1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MJREC     1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month"
                       3 "1 or more months ago but less than 6 months"
                       4 "6 or more months ago but less than 1 year"
                       5 "1 or more years ago but less than 3 years"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED MARIJUANA" ;
label define MJDAY30A  81 "NEVER USED MARIJUANA Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA" 98 "BLANK (NO ANSWER)" ;
label define MJAV30A   81 "NEVER USED MARIJUANA Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA" 98 "BLANK (NO ANSWER)" ;
label define MJAMT30A  1 "Less than 10 joints in the past 30 days"
                       2 "10 to 20 joints in the past 30 days"
                       3 "About 1 ounce in the past 30 days"
                       4 "About 2 ounces in the past 30 days"
                       5 "3 to 4 ounces in the past 30 days"
                       6 "5 to 6 ounces in the past 30 days"
                       7 "Unspecified but > 6 ounces in the past 30 days"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 30 DAYS"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS" ;
label define MJYRFREQ  1 "Several times a day" 2 "Daily"
                       3 "Almost daily (3 to 6 days a week)"
                       4 "1 or 2 days a week"
                       5 "Several times a month (about 25 to 51 days)"
                       6 "1 to 2 times a month (12 to 24 days a year)"
                       7 "Every other month or so (6 to 11 days a year)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 or 2 days in the past 12 months"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define MJJOINT   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define MJPIPE    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define MJBAKE    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define MJCHEW    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define MJNEWA    6 "Can with holes" 7 "One hitter" 8 "Boiled with tea"
                       9 "Smoky small room (burn in small room like bathroom)"
                       10 "With banana peels" 11 "Shot gun"
                       12 "Chewing/eating"
                       13 "Through an apple made like a pipe"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define MJNOSP    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define AS7READ   1 "Wants interviewer to read questions"
                       2 "Wants to do it himself/herself" 98 "BLANK" ;
label define GAS       1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define SPPAINT   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define AEROS     1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define GLUE      1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define SOLVENT   1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define AMYLNIT   1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define ETHER     1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define NITOXID   1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define CLEFLU    1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHNEWA   356 "Dexies" 502 "Spray paints"
                       504 "Shoeshine liquid, Glue, Toluene"
                       506 "Amyl nitrite (poppers, locker room)"
                       509 "Correction fluids, Degreasers, Cleaning"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, Felt-tip pens" 512 "Rush, Incense"
                       514 "Carbona" 516 "Freon" 518 "Nail Polish"
                       519 "Helium" 521 "Propane" 522 "TV Tuner"
                       523 "Matches" 605 "PCP"
                       801 "OTHER Drugs, NOT SPECIFIED" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol" 813 "Cigarettes and Tobacco"
                       814 "Caffeine" 991 "NEVER USED INHALANTS"
                       998 "BLANK (NO ANSWER)" ;
label define INHNEWB   517 "Tolyol" 991 "NEVER USED INHALANTS"
                       998 "BLANK (NO ANSWER)" ;
label define INHNOSP   1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHDKNAM  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHAGE    181 "NEVER USED INHALANTS Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED INHALANTS" 194 "DONT KNOW"
                       195 "BAD DATA Logically assigned"
                       198 "BLANK (NO ANSWER)" ;
label define INHTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED INHALANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 96 "MULTIPLE RESPONSE"
                       98 "BLANK (NO ANSWER)" ;
label define INHREC    1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month"
                       3 "1 or more months ago but less than 6 months"
                       4 "6 or more months ago but less than 1 year"
                       5 "1 or more years ago but less than 3 years"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHYRFRQ  1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 days)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 to 2 days in the past 12 months"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 12 MOS."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define GAS30A    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define SPPAN30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 12 MOS."
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define AEROS30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWWER)" ;
label define GLUE30A   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USED INHALANT PAST 30 DAYS"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define SOLVN30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 12 MOS."
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define AMLNT30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWWER)" ;
label define ETHER30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USED INHALANT PAST 30 DAYS"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define NOX30A    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 12 MOS."
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define CLFL30A   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define INNEW30A  504 "Shoeshine liquid, Glue, Toluene"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, Felt-tip pens"
                       518 "Nail polish, Acetone" 522 "TV Tuner"
                       523 "Matches" 801 "OTHER Drugs, NOT SPECIFIED"
                       805 "Cocaine, Coke" 806 "Crack" 814 "Caffeine"
                       991 "NEVER USED INHALANTS" 993 "NOT APPLICABLE"
                       998 "BLANK (NO ANSWER)" ;
label define INNEW30B  504 "Shoeshine liquid, Glue, Toluene"
                       991 "NEVER USED INHALANTS" 993 "NOT APPLICABLE"
                       998 "BLANK (NO ANSWER)" ;
label define IN30NOSP  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define INH30NO   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHDY30A  81 "NEVER USED INHALANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHEFF    1 "Enough to feel it a little"
                       2 "Enough to feel it a lot" 3 "Enough to get high"
                       4 "Enough so that you staggered or dropped"
                       5 "Enough to feel you were going to pass out"
                       6 "Something else - unspecified"
                       7 "Didnt feel it, didnt use much"
                       8 "Sniffed out of curiosity once"
                       11 "Enough for a head rush"
                       12 "Didnt feel it,just like the smell"
                       81 "NEVER USED INHALANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 96 "MULTIPLE RESPONSE"
                       98 "BLANK (NO ANSWER)" ;
label define INHPO     1 "Yes" 2 "No"
                       81 "NEVER USED INHALANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHQNC1   1 "QUESTION 1 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC2   2 "QUESTION 2 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC3   3 "QUESTION 3 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC4   4 "QUESTION 4 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC5   5 "QUESTION 5 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC6   6 "QUESTION 6 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC7   7 "QUESTION 7 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC8   8 "QUESTION 8 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC9   9 "QUESTION 9 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC10  10 "ALL QUESTIONS WERE CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHANSY   1 "Yes" 2 "No" 98 "BLANK" ;
label define COCOPP    181 "NEVER HAD A CHANCE TO TRY COCAINE"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER HAD A CHANCE TO TRY COCAINE"
                       194 "DONT KNOW" 197 "REFUSED" 198 "BLANK (NO ANSWER)" ;
label define COCAGE    181 "NEVER USED COCAINE Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED COCAINE" 195 "BAD DATA" ;
label define COCTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED COCAINE Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE" 98 "BLANK (NO ANSWER)" ;
label define COCREC    1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED COCAINE" ;
label define COCUS30A  81 "NEVER USED COCAINE Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE" ;
label define COCYRFRQ  1 "Daily" 2 "Almost daily (3 to 6 days a week)"
                       3 "1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 days)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COCSNIFF  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCSWAL   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCIV     1 "Response circled" 2 "Response not circled"
                       3 "Cocaine use LOGICALLY IMPUTED"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE IN PAST 12 MOS."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define FREEBASE  1 "Response circled" 2 "Response not circled"
                       3 "Cocaine use LOGICALLY IMPUTED"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCNEWA   6 "Lasing (sic) joints and bongs" 7 "On my gums"
                       8 "Freeze, put on tongue, etc"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCNEWB   7 "On my gums"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCNOSP   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MONTHS"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define CONDLREC  1 "Within past month (30 days)"
                       2 "More than 1 month ago but less than 6 months"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED COCAINE"
                       93 "NEVER USED COCAINE WITH A NEEDLE" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define CRAKREC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED CRACK" 97 "REFUSED" ;
label define CRKAM30A  981 "NEVER USED Logically assigned"
                       983 "DID NOT USE CRACK IN PAST 30 DAYS"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED CRACK"
                       993 "DID NOT USE CRACK IN PAST 30 DAYS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define CRAKBUCK  9981 "NEVER USED COCAINE Logically assigned"
                       9983 "DID NOT USE CRACK PAST 30 DAYS"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED CRACK"
                       9993 "DID NOT USE CRACK IN PAST 30 DAYS"
                       9997 "REFUSED" ;
label define COCAM30A  1 "Less than 1/4 gram (about 4 big lines)"
                       2 "About 1/4 gram in the past 30 days"
                       3 "About 1/2 gram in the past 30 days"
                       4 "About 1 gram in the past 30 days"
                       5 "About 2 grams in the past 30 days"
                       6 "About 3 grams in the past 30 days"
                       7 "Unspecified but >3 grams in past 30 days"
                       8 "4 grams in the past 30 days"
                       10 "Unspecified but >3 grams in past 30 days"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE IN PAST 30 DAYS"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define COCBUCK   9981 "NEVER USED COCAINE Logically assigned"
                       9983 "DID NOT USE COCAINE PAST 30 DAYS"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED COCAINE"
                       9993 "DID NOT USE COCAINE IN PAST 30 DAYS"
                       9994 "DONT KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define AS9READ   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself" 98 "BLANK" ;
label define LSD       1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define PEYOTE    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define MESC      1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define PSILCY    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define PCP       1 "Response circled" 2 "Response not circled"
                       3 "PCP use LOGICALLY IMPUTED"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define ECSTASY   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define HALNEWA   210 "Paxipam" 336 "Diet pills"
                       604 "Psilocybin Mushrooms"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 608 "ORGAN-Z5"
                       614 "MDA" 616 "DMT" 617 "Morning glory seeds"
                       802 "THC, Cannabinol" 991 "NEVER USED HALLUCINOGENS"
                       998 "BLANK (NO ANSWER)" ;
label define HALNEWB   607 "OTHER HALLUCINOGEN, NOT SPECIFIED"
                       801 "OTHER Drugs, NOT SPECIFIED"
                       991 "NEVER USED HALLUCINOGENS" 998 "BLANK (NO ANSWER)" ;
label define HALNOSP   1 "Response circled" 2 "Response not circled"
                       3 "Hallucinogen use LOGICALLY IMPUTED"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define HALDKNAM  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define HALLOPP   181 "NEVER HAD A CHANCE TO TRY HALLUCINOGENS"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER HAD A CHANCE TO TRY HALLUCINOGENS"
                       194 "DONT KNOW" 198 "BLANK (NO ANSWER)" ;
label define HALLAGE   181 "NEVER USED HALLUCINOGENS Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED HALLUCINOGENS" 194 "DONT KNOW"
                       195 "BAD DATA" 198 "BLANK (NO ANSWER)" ;
label define HALLTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define HALLREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define HAL30USE  81 "NEVER USED HALLUCINOGENS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define HALYRFRQ  1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 days)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 to 2 days in the past 12 months"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       83 "DID NOT USE HALLUCINOGEN PAST 12 MOS."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGEN IN THE PAST 12 MONTHS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define PCPREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED PCP" ;
label define AS10READ  1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself" 98 "BLANK" ;
label define HEROPP    181 "NEVER HAD A CHANCE TO TRY HEROIN"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER HAD A CHANCE TO TRY HEROIN" 194 "DONT KNOW"
                       198 "BLANK (NO ANSWER)" ;
label define HERAGE    181 "NEVER HAD A CHANCE TO TRY HEROIN"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER HAD A CHANCE TO TRY HEROIN"
                       198 "BLANK (NO ANSWER)" ;
label define HERTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED HEROIN Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN" 98 "BLANK (NO ANSWER)" ;
label define HERREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOCIGALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED HEROIN" 98 "BLANK (NO ANSWER)" ;
label define HER30USE  81 "NEVER USED HEROIN Logically assigned"
                       91 "NEVER USED HEROIN" 98 "BLANK (NO ANSWER)" ;
label define HERNEEDL  1 "Yes, have used heroin with a needle"
                       2 "No, have used heroin, but not with a needle"
                       3 "Yes, have used heroin with needle Logically assign."
                       81 "NEVER USED HEROIN Logically assigned"
                       91 "NEVER USED HEROIN" 98 "BLANK (NO ANSWER)" ;
label define HRNDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED HEROIN"
                       93 "NEVER USED HEROIN WITH A NEEDLE"
                       98 "BLANK (NO ANSWER)" ;
label define AS11READ  1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself" 98 "BLANK" ;
label define CDCIG     1 "Response circled" 2 "Response not circled"
                       3 "Did not try to cut down on any drug in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log."
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define CDALC     1 "Response circled" 2 "Response not circled"
                       3 "Did not try to cut down on any drug in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log."
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define CDSED     1 "Response circled" 2 "Response not circled"
                       3 "Did not try to cut down on any drug in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log."
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define CDTRAN    1 "Response circled" 2 "Response not circled"
                       3 "Did not try to cut down on any drug in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log."
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define CDSTM     1 "Response circled" 2 "Response not circled"
                       3 "Did not try to cut down on any drug in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define CDANAL    1 "Response circled" 2 "Response not circled"
                       3 "Did not try to cut down on any drug in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define CDMJ      1 "Response circled" 2 "Response not circled"
                       3 "Did not try to cut down on any drug in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define CDINH     1 "Response circled" 2 "Response not circled"
                       3 "Did not try to cut down on any drug in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define CDCOC     1 "Response circled" 2 "Response not circled"
                       3 "Did not try to cut down on any drug in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS."
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define CDHALL    1 "Response circled" 2 "Response not circled"
                       3 "Did not try to cut down on any drug in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define CDHER     1 "Response circled" 2 "Response not circled"
                       3 "Did not try to cut down on any drug in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define CDOTHOP   1 "Response circled" 2 "Response not circled"
                       3 "Did not try to cut down on any drug in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define CDNONE    1 "Response circled" 2 "Response not circled"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define EFFCIG    1 "Response circled" 2 "Response not circled"
                       3 "Did not need more of any drug used for same effect"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define EFFALC    1 "Response circled" 2 "Response not circled"
                       3 "Did not need more of any drug used for same effect"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define EFFSED    1 "Response circled" 2 "Response not circled"
                       3 "Did not need more of any drug used for same effect"
                       83 "DID NOT USE ANY DRUGS PAST 12 MONTHS LOG. ASSIGNED"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define EFFTRAN   1 "Response circled" 2 "Response not circled"
                       3 "Did not need more of any drug used for same effect"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define EFFSTM    1 "Response circled" 2 "Response not circled"
                       3 "Did not need more of any drug used for same effect"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define EFFANAL   1 "Response circled" 2 "Response not circled"
                       3 "Did not need more of any drug used for same effect"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define EFFMJ     1 "Response circled" 2 "Response not circled"
                       3 "Did not need more of any drug used for same effect"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define EFFINH    1 "Response circled" 2 "Response not circled"
                       3 "Did not need more of any drug used for same effect"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define EFFCOC    1 "Response circled" 2 "Response not circled"
                       3 "Did not need more of any drug used for same effect"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define EFFHALL   1 "Response circled" 2 "Response not circled"
                       3 "Did not need more of any drug used for same effect"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define EFFHER    1 "Response circled" 2 "Response not circled"
                       3 "Did not need more of any drug used for same effect"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define EFFOTHOP  1 "Response circled" 2 "Response not circled"
                       3 "Did not need more of any drug used for same effect"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define EFFNONE   1 "Response circled" 2 "Response not circled"
                       3 "Did not need more of any drug used for same effect"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define UDAYCIG   1 "Response circled" 2 "Response not circled"
                       3 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define UDAYALC   1 "Response circled" 2 "Response not circled"
                       3 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define UDAYSED   1 "Response circled" 2 "Response not circled"
                       3 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define UDAYTRAN  1 "Response circled" 2 "Response not circled"
                       3 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define UDAYSTM   1 "Response circled" 2 "Response not circled"
                       3 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define UDAYANAL  1 "Response circled" 2 "Response not circled"
                       3 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define UDAYMJ    1 "Response circled" 2 "Response not circled"
                       3 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define UDAYINH   1 "Response circled" 2 "Response not circled"
                       3 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define UDAYCOC   1 "Response circled" 2 "Response not circled"
                       3 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define UDAYHALL  1 "Response circled" 2 "Response not circled"
                       3 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define UDAYHER   1 "Response circled" 2 "Response not circled"
                       3 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define UDAYOTH   1 "Response circled" 2 "Response not circled"
                       3 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define UDAYNONE  1 "Response circled" 2 "Response not circled"
                       3 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define DEPCIG    1 "Response circled" 2 "Response not circled"
                       3 "Did not feel like had to have any drug used past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define DEPALC    1 "Response circled" 2 "Response not circled"
                       3 "Did not feel like had to have any drug used past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define DEPSED    1 "Response circled" 2 "Response not circled"
                       3 "Did not feel like had to have any drug used past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define DEPTRAN   1 "Response circled" 2 "Response not circled"
                       3 "Did not feel like had to have any drug used past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define DEPSTM    1 "Response circled" 2 "Response not circled"
                       3 "Did not feel like had to have any drug used past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define DEPANAL   1 "Response circled" 2 "Response not circled"
                       3 "Did not feel like had to have any drug used past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define DEPMJ     1 "Response circled" 2 "Response not circled"
                       3 "Did not feel like had to have any drug used past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define DEPINH    1 "Response circled" 2 "Response not circled"
                       3 "Did not feel like had to have any drug used past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define DEPCOC    1 "Response circled" 2 "Response not circled"
                       3 "Did not feel like had to have any drug used past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define DEPHALL   1 "Response circled" 2 "Response not circled"
                       3 "Did not feel like had to have any drug used past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define DEPHER    1 "Response circled" 2 "Response not circled"
                       3 "Did not feel like had to have any drug used past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define DEPOTHOP  1 "Response circled" 2 "Response not circled"
                       3 "Did not feel like had to have any drug used past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define DEPNONE   1 "Response circled" 2 "Response not circled"
                       3 "Did not feel like had to have any drug used past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define WSCIG     1 "Response circled" 2 "Response not circled"
                       3 "Did not have withdrawal symptoms in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define WSALC     1 "Response circled" 2 "Response not circled"
                       3 "Did not have withdrawal symptoms in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define WSSED     1 "Response circled" 2 "Response not circled"
                       3 "Did not have withdrawal symptoms in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define WSTRAN    1 "Response circled" 2 "Response not circled"
                       3 "Did not have withdrawal symptoms in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define WSSTM     1 "Response circled" 2 "Response not circled"
                       3 "Did not have withdrawal symptoms in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define WSANAL    1 "Response circled" 2 "Response not circled"
                       3 "Did not have withdrawal symptoms in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define WSMJ      1 "Response circled" 2 "Response not circled"
                       3 "Did not have withdrawal symptoms in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define WSINH     1 "Response circled" 2 "Response not circled"
                       3 "Did not have withdrawal symptoms in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define WSCOC     1 "Response circled" 2 "Response not circled"
                       3 "Did not have withdrawal symptoms in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define WSHALL    1 "Response circled" 2 "Response not circled"
                       3 "Did not have withdrawal symptoms in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define WSHER     1 "Response circled" 2 "Response not circled"
                       3 "Did not have withdrawal symptoms in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define WSOTHOP   1 "Response circled" 2 "Response not circled"
                       3 "Did not have withdrawal symptoms in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define WSNONE    1 "Response circled" 2 "Response not circled"
                       3 "Did not have withdrawal symptoms in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned"
                       85 "BAD DATA Log. assigned"
                       93 "DID NOT USE ANY DRUGS IN PAST 12 MONTHS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define ICELIFE   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       81 "NEVER USED ICE Logically assigned"
                       98 "BLANK (NO ANSWER)" ;
label define ICEREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       6 "10 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED ICE Logically assigned"
                       91 "NEVER USED ICE" 98 "BLANK (NO ANSWER)" ;
label define AS12READ  1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself" 98 "BLANK" ;
label define GNNDLLIF  1 "Response circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       81 "NEVER USED NEEDLE TO TAKE DRUG Log. assigned"
                       91 "NEVER USED A NEEDLE TO TAKE A DRUG" ;
label define GNNDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED ANY DRUG FOR NONMDCL RSN"
                       91 "NEVER USED ANY DRUG FOR NONMEDICAL RSNS"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG" ;
label define GNNDLSED  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. assigned"
                       83 "NEVER USED NEEDLE TO TAKE DRUG Log. assigned"
                       85 "BAD DATA Log. assgnd"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLTRA  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY LISTED DRUGS Log. assgnd"
                       83 "NEVER USED ANY DRUGS LIST ABOVE Log. assigned"
                       85 "NEVER USED NEEDLE TO TAKE DRUG Log. asigned"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLSTM  1 "Response circled" 2 "Response not circled"
                       3 "Response circled Log. imputed"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. assigned"
                       83 "NEVER USED NEEDLE TO TAKE DRUG Log. assg"
                       85 "BAD DATA Log. assgnd"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLANL  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. assigned"
                       83 "NEVER USED NEEDLE TO TAKE DRUG Log. assg"
                       85 "BAD DATA Log. assgnd"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLMJ   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. assigned"
                       83 "NEVER USED NEEDLE TO TAKE DRUG Log. assigned"
                       85 "BAD DATA Log. assgnd"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLINH  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. assigned"
                       83 "NEVER USED NEEDLE TO TAKE DRUG Log. assg"
                       85 "BAD DATA Log. assgnd"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLCOC  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. assigned"
                       83 "NEVER USED NEEDLE TO TAKE DRUG Log. assg"
                       85 "BAD DATA Log. assgnd"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLHAL  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. assigned"
                       83 "NEVER USED NEEDLE TO TAKE DRUG Log. assg"
                       85 "BAD DATA Log. assgnd"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLHER  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. assigned"
                       83 "NEVER USED NEEDLE TO TAKE DRUG Log. assg"
                       85 "BAD DATA Log. assgnd"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLOPT  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. assigned"
                       83 "NEVER USED NEEDLE TO TAKE DRUG Log. assg"
                       85 "BAD DATA Log. assgnd"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLNON  2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. assigned"
                       83 "NEVER USED NEEDLE TO TAKE DRUG Log. assg"
                       85 "BAD DATA Log. assgnd"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLSHR  1 "Yes" 2 "No" 81 "NEVER SHARED A NEEDLE Log. assgnd"
                       91 "NEVER SHARED A NEEDLE" 98 "BLANK (NO ANSWER)" ;
label define AS13READ  1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself" 98 "BLANK" ;
label define NOBOOZYR  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       85 "BAD DATA Log. assgnd" 98 "BLANK (NO ANSWER)" ;
label define ALCAGGR   1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define ALCARGUM  1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define ALCABSNT  1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define ALCHIGH   1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define ALCJOB    1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define ALCMATCD  1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define ALCRELCD  1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define ALCFRDCD  1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define ALCTOSS   1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define ALCHOLIC  1 "Yes" 2 "No" 94 "DONT KNOW" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define ALCDRUNK  1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define ALCINTOX  1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define ALCREM    1 "Yes" 2 "No" 94 "DONT KNOW" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define ALCQUICK  1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define ALCMORN   1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define ALCSHOOK  1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define ALCALONE  1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define ALCBRKPM  1 "Yes" 2 "No" 94 "DONT KNOW" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOZYR=1 or 3)" ;
label define AS13NONE  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       85 "BAD DATA Log. assgnd" 98 "BLANK (NO ANSWER)" ;
label define DRDEPRSS  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (AS13NONE=1 or 3)" ;
label define DEPDRG1A  112 "Restoril"
                       116 "Methaqualone (including Sopor, Quaalude)"
                       120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       121 "USED SEDATIVE, DONT KNOW NAME" 123 "Unisom"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       332 "Ephedrine" 339 "Amphetamines (speed)"
                       348 "Crystal" 401 "Darvon"
                       501 "Gasoline or lighter fluids"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       808 "All of the ones Ive tried" 812 "Cigars"
                       813 "Cigarettes, Tobacco" 900 "NON-DRUG REASON"
                       994 "DONT KNOW" 995 "BAD DATA" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRDEPRSS=2,99)" ;
label define DEPDRG2A  120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       201 "Valium" 209 "Xanax" 332 "Ephedrine"
                       336 "Diet pills" 420 "OTHER Analgesic, NOT SPECIFIED"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRDEPRSS=2,99)" ;
label define DEPDRG3A  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (Speed or Crank)"
                       409 "Tylenol with Codeine"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRDEPRSS=2,99)" ;
label define DEPDRG4A  807 "Alcohol" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRDEPRSS=2,99)" ;
label define DRARGUM   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       85 "BAD DATA Log. assgnd" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ARGDRG1A  120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       123 "Unisom" 209 "Xanax"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       332 "Ephedrine" 336 "Diet pills" 348 "Crystal"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, Felt-tip pens"
                       601 "LSD (acid, white lightning)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       812 "Cigars" 813 "Cigarettes, Tobacco"
                       816 "Smokeless tobacco - snuff/chewing"
                       900 "NON-DRUG REASON" 994 "DONT KNOW" 995 "BAD DATA"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRARGUM=2,99)" ;
label define ARGDRG2A  120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       201 "Valium"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       325 "USED STIMULANT, DONT KNOW NAME" 336 "Diet pills"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       813 "Cigarettes, Tobacco" 900 "NON-DRUG REASON"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRARGUM=2,99)" ;
label define ARGDRG3A  201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       409 "Tylenol with Codeine" 803 "Marijuana"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRARGUM=2,99)" ;
label define DRALONE   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (AS13NONE=1 or 3)" ;
label define ALNDRG1A  116 "Methaqualone (including Sopor, Quaalude)"
                       120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       121 "USED SEDATIVE, DONT KNOW NAME" 123 "Unisom"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       332 "Ephedine" 510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       813 "Cigarettes, Tobacco1" 900 "NON-DRUG REASON"
                       994 "DONT KNOW" 995 "BAD DATA" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRALONE=2,99)" ;
label define ALNDRG2A  120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       336 "Diet pills" 510 "OTHER Inhalant, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, Tobacco"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRALONE=2,99)" ;
label define ALNDRG3A  221 "OTHER Tranquilizer, NOT SPECIFIED1"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRALONE=2,99)" ;
label define DRANX     1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (AS13NONE=1 or 3)" ;
label define ANXDRG1A  120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       122 "Sleep Aid" 201 "Valium" 209 "Xanax"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       325 "USED STIMULANT, DONT KNOW NAME"
                       329 "Speckled Eggs, Robins Eggs" 332 "Ephedrine"
                       336 "Diet pills" 339 "Amphetamines (speed)"
                       348 "Crystal" 510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, Felt-tip pens" 513 "Tulio Osica"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       808 "All of the ones Ive tried" 812 "Cigars"
                       813 "Cigarettes, Tobacco" 814 "Caffeine"
                       900 "NON-DRUG REASON" 994 "DONT KNOW" 995 "BAD DATA"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRANX=2,99)" ;
label define ANXDRG2A  120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       325 "USED STIMULANT, DONT KNOW NAME" 336 "Diet pills"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       605 "PCP (angel dust, phencyclidine)" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 900 "NON-DRUG REASON"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRANX=2,99)" ;
label define ANXDRG3A  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)" 803 "Marijuana"
                       807 "Alcohol" 900 "NON-DRUG REASON"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRANX=2,99)" ;
label define DRHEALTH  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       85 "BAD DATA Log. assgnd" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLTDRG1A  120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       325 "USED STIMULANT, DONT KNOW NAME"
                       339 "Amphetamine (speed)" 348 "Crystal" 426 "Fiorinal"
                       430 "Aspirin, Ecotrine" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       812 "Cigars" 813 "Cigarettes, Tobacco"
                       900 "NON-DRUG REASON" 994 "DONT KNOW" 995 "BAD DATA"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRHEALTH=2,99)" ;
label define HLTDRG2A  120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol" 813 "Cigarettes, Tobacco"
                       900 "NON-DRUG REASON" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRHEALTH=2,99)" ;
label define HLTDRG3A  221 "OTHER Tranquilizer, NOT SPECIFIED" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRHEALTH=2,99)" ;
label define DRNTHINK  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (AS13NONE=1 or 3)" ;
label define NTKDRG1A  116 "Methaqualone (including Sopor, Quaalude)"
                       120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       122 "Sleep Aid" 201 "Valium" 209 "Xanax"
                       222 "USED TRANQUILIZER, DONT KNOW NAME"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       348 "Crystal" 510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, Felt-tip pens"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       812 "Cigars" 813 "Cigarettes, Tobacco"
                       900 "NON-DRUG REASON" 995 "BAD DATA"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRNTHINK=2,99)" ;
label define NTKDRG2A  120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       409 "Tylenol with Codeine" 417 "Morphine"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 900 "NON-DRUG REASON"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRNTHINK=2,99)" ;
label define NTKDRG3A  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       603 "Mescaline" 605 "PCP (angel dust, phencyclidine)"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRNTHINK=2,99)" ;
label define NTKDRG4A  803 "Marijuana" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRNTHINK=2,99)" ;
label define DRUPSET   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (AS13NONE=1 or 3)" ;
label define UPSDRG1A  120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       122 "Sleep Aid" 201 "Valium"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       325 "USED STIMULANT, DONT KNOW NAME" 332 "Ephedrine"
                       336 "Diet pills" 348 "Crystal"
                       409 "Tylenol with Codeine"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, Felt-tip pens"
                       601 "LSD (acid, white lightning)"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       813 "Cigarettes, Tobacco" 814 "Caffeine" 815 "Coffee"
                       817 "Hardstuff" 900 "NON-DRUG REASON" 994 "DONT KNOW"
                       995 "BAD DATA" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRUPSET=2,99)" ;
label define UPSDRG2A  120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       336 "Diet pills" 420 "OTHER Analgesic, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, Tobacco"
                       900 "NON-DRUG REA" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRUPSET=2,99)" ;
label define UPSDRG3A  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRUPSET=2,99)" ;
label define DRLSWORK  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (AS13NONE=1 or 3)" ;
label define LSWDRG1A  120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       201 "Valium" 222 "USED TRANQUILIZER, DONT KNOW NAME"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       325 "USED STIMULANT, DONT KNOW NAME" 348 "Crystal"
                       409 "Tylenol with Codeine"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       808 "All of the ones Ive tried"
                       813 "Cigarettes, Tobacco" 900 "NON-DRUG REASON"
                       995 "BAD DATA" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRLSWORK=2,99)" ;
label define LSWDRG2A  201 "Valium"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       601 "LSD (acid, white lightning)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 900 "NON-DRUG REASON"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRLSWORK=2,99)" ;
label define LSWDRG3A  803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRLSWORK=2,99)" ;
label define DRSUSPIC  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (AS13NONE=1 or 3)" ;
label define SSPDRG1A  116 "Methaqualone (including Sopor, Quaalude)"
                       120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       122 "Sleep Aid" 322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       348 "Crystal" 353 "No-Doz"
                       511 "Markers, Felt-tip pens"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       808 "All of the ones Ive tried"
                       813 "Cigarettes, Tobacco1" 900 "NON-DRUG REASON"
                       994 "DONT KNOW" 995 "BAD DATA" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRSUSPIC=2,99)" ;
label define SSPDRG2A  702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       807 "Alcohol" 813 "Cigarettes, Tobacco"
                       900 "NON-DRUG REASON" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRSUSPIC=2,99)" ;
label define SSPDRG3A  803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRSUSPIC=2,99)" ;
label define DRCOPE    1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (AS13NONE=1 or 3)" ;
label define CPEDRG1A  120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       122 "Sleep Aid" 322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       348 "Crystal" 426 "Fiorinal"
                       510 "OTHER Inhalant, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       808 "All of the ones Ive tried"
                       813 "Cigarettes, Tobacco1" 900 "NON-DRUG REASON"
                       994 "DONT KNOW" 995 "BAD DATA" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRCOPE=2,99)" ;
label define CPEDRG2A  201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol" 813 "Cigarettes, Tobacco"
                       900 "NON-DRUG REASON" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRCOPE=2,99)" ;
label define CPEDRG3A  803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (DRCOPE=2,99)" ;
label define DREMGMED  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (AS13NONE=1 or 3)" ;
label define EMDRG1A   603 "Mescaline" 702 "Heroin" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 900 "NON-DRUG REASON"
                       995 "BAD DATA" 998 "BLANK"
                       999 "LEGITIMATE SKIP (DREMGMED=2,99)" ;
label define EMDRG2A   803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       900 "NON-DRUG REASON" 998 "BLANK"
                       999 "LEGITIMATE SKIP (DREMGMED=2,99)" ;
label define EMDRG3A   806 "Crack" 807 "Alcohol" 998 "BLANK"
                       999 "LEGITIMATE SKIP (DREMGMED=2,99)" ;
label define EMDRG4A   601 "LSD (acid, white lightning)" 998 "BLANK"
                       999 "LEGITIMATE SKIP (DREMGMED=2,99)" ;
label define RSKPKCIG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKTRYMJ  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKMJOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKMJREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKTRYPCP  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKPCPREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKTRYHER  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 92 "ILLEGIBLE" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKHERREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKTRYCOC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKCOCOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKCOCREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKCRKOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKANSOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWWER)" ;
label define RKANSREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RK2DRINK  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RK5DRINK  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKBINGE  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HIGHBP    1 "Yes" 2 "No" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define BPMED     1 "Yes" 2 "No" 92 "ILLEGIBLE" 94 "DONT KNOW"
                       98 "BLANK" 99 "LEGITIMATE SKIP" ;
label define WALKPAIN  1 "Yes" 2 "No" 94 "DONT KNOW" 98 "BLANK" ;
label define TIMEPAIN  1 "Yes" 2 "No" 98 "BLANK" ;
label define UPSHOR    1 "Yes" 2 "No" 98 "BLANK" ;
label define ASTHMA    1 "Yes" 2 "No" 92 "ILLEGIBLE" 94 "DONT KNOW"
                       98 "BLANK" ;
label define TRPSYCH   1 "Yes" 2 "No" 92 "ILLEGIBLE" 94 "DONT KNOW"
                       98 "BLANK" ;
label define HEART     1 "Yes" 2 "No" 94 "DONT KNOW" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define FLU       1 "Yes" 2 "No" 94 "DONT KNOW" 98 "BLANK" ;
label define ALLERG    1 "Yes" 2 "No" 94 "DONT KNOW" 98 "BLANK" ;
label define HOSPYR    1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK" ;
label define SOREYR    1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK" ;
label define RUNNYYR   1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK" ;
label define COUGHYR   1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK" ;
label define PHLEGMYR  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK" ;
label define HEALTHYR  1 "Excellent" 2 "Very good" 3 "Good" 4 "Fair" 5 "Poor"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK" ;
label define HELTHINS  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MARITAL   1 "Married" 2 "Widowed" 3 "Divorced or separated"
                       4 "Has never married" 85 "BAD DATA Log. assgnd"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP (IRAGE<15)" ;
label define NOMARR    85 "BAD DATA Log. assgnd" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (IRAGE<15 or MARITAL=4)" ;
label define WORKSTAT  1 "Working full-time, 35 hours or more a week"
                       2 "Working part-time, less than 35 hours a week"
                       3 "Have job but out: illness/leave/furlough"
                       4 "Unemployed or laid off and looking for week"
                       5 "Unemployed and not looking for work"
                       6 "Full-time homemaker only" 7 "In school only"
                       8 "Retired" 9 "Disabled, not able to work"
                       10 "Something else (NOT SPECIFIED)"
                       11 "Unable to work - taking care of ill relatives"
                       12 "About to start work"
                       13 "Contracts for work (eg. Musician)"
                       14 "Welfare (AFDC)"
                       15 "Out of work - Termination - Injury"
                       16 "Just got out of school" 18 "Drop out of school"
                       19 "Full time but less than 35 hours per week"
                       21 "Volunteer" 22 "Babysitting" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK" ;
label define PAYMO     85 "BAD DATA Log. assgnd" 91 "NEVER WORKED FOR PAY"
                       94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (WORKSTAT<4)" ;
label define PAYYR     91 "NEVER WORKED FOR PAY" 94 "DONT KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (WORKSTAT<4)" ;
label define ROCCUP2   990 "OCCUPATION NOT REPORTED" 995 "BAD DATA"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define BUSINES2  990 "INDUSTRY NOT REPORTED" 995 "BAD DATA"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define SECTOR    1 "Manufacturing," 2 "Wholesale trade,"
                       3 "Retail trade, or" 4 "Something else? (SPECIFY)"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK" 99 "LEGITIMATE SKIP" ;
label define NO5JOB    94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORKDAYS  94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WORKBLAH  85 "BAD DATA Log. assgnd" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CWE       1 "Respondent" 2 "Someone else (NOT SPECIFIED)"
                       3 "Income Contributed Equally" 4 "No one"
                       11 "Head of Household,Employer"
                       12 "Spouse,Ex-husband supports"
                       13 "Live-in partner,fiancee" 14 "Mother" 15 "Father"
                       16 "Daughter" 17 "Son" 18 "Sister" 19 "Brother"
                       20 "Grandmother" 21 "Grandfather"
                       22 "Other female blood relative"
                       23 "Other male blood relative" 24 "Mother-in-law"
                       25 "Father-in-law" 26 "Other female in-laws"
                       27 "Other male in-laws" 28 "Close female friend"
                       29 "Close male friend"
                       30 "Other female acquaintance, roommate"
                       31 "Other male acquaintance, roommate"
                       32 "Step-mother" 33 "Step-father"
                       38 "Other step relative, male"
                       40 "Friend (sex unspecified),boarder" 41 "Parents"
                       42 "Grandparents" 44 "Foster mother, female guardian"
                       45 "Foster father, male guardian"
                       50 "Multiple people listed"
                       51 "Relative, sex not specified"
                       52 "Roomate, sex not specified" 92 "ILLEGIBLE"
                       94 "DONT KNOW" 95 "BAD DATA" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK"
                       99 "LEG. SKIP (RESP IS ONLY ADULT 18 OR OLDER)" ;
label define FULLPART  1 "Full-time" 2 "Part-time"
                       3 "Chief source of income does not work"
                       94 "DONT KNOW" 95 "BAD DATA" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK" 99 "LEGITIMATE SKIP" ;
label define CWEOCC2   990 "OCCUPATION NOT REPORTED" 994 "DONT KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (CWE=1,3,99 or FULLPART=" ;
label define CWEBUS2   990 "INDUSTRY NOT REPORTED" 994 "DONT KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (CWE=1,3,99 or FULLPART=" ;
label define CWESECTR  1 "Manufacturing," 2 "Wholesale trade,"
                       3 "Retail trade, or" 4 "Something else? (SPECIFY)"
                       94 "DONT KNOW" 95 "BAD DATA" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK" 99 "LEGITIMTE SKIP" ;
label define EDUC      0 "No schooling" 1 "First Grade" 2 "Second grade"
                       3 "Third grade" 4 "Fourth grade" 5 "Fifth grade"
                       6 "Sixth grade" 7 "Seventh Grade" 8 "Eighth grade"
                       9 "Ninth grade" 10 "Tenth grade" 11 "Eleventh grade"
                       12 "Twelfth grade" 13 "One year college"
                       14 "2 years college" 15 "3 years college"
                       16 "4 years college" 17 "Graduate/professional school"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK" ;
label define GRADHS    1 "YES" 2 "NO" 92 "ILLEGIBLE" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK" 99 "LEGITIMATE SKIP" ;
label define DIPLOMA   1 "High school diploma" 2 "GED certificate"
                       3 "Neither of the above" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK"
                       99 "LEGITIMATE SKIP(EDUC>12,GRADHS=2/IRAGE<1" ;
label define ENROLLD   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK" ;
label define STUDENT   1 "A full-time student" 2 "A part-time student"
                       97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP (ENROLLD=2)" ;
label define SCHDAYS   92 "ILLEGIBLE" 94 "DONT KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (ENROLLD=2)" ;
label define SKIPPED   97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (ENROLLD=2)" ;
label define SCHPLANS  1 "Has plans to enroll in a school in future"
                       2 "Has completed all schooling" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP (IRAGE>22)" ;
label define MILES     99991 "HAS NEVER DRIVEN A MOTOR VEHICLE"
                       99994 "DONT KNOW" 99997 "REFUSED"
                       99998 "BLANK (NO ANSWER)"
                       99999 "LEGITIMATE SKIP (IRAGE<15)" ;
label define ACCID     1 "Yes" 2 "No" 3 "Did not drive in past 12 months"
                       85 "BAD DATA Log. assgnd" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP (IRAGE<15 or MILES=99991" ;
label define NOCHILD   94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (IRAGE<15)" ;
label define TOTPEOP   97 "REFUSED" 98 "BLANK" ;
label define MOTHER    0 "No" 1 "Yes" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define FATHER    0 "No" 1 "Yes" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define STEPMOM   0 "No" 1 "Yes" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define STEPDAD   0 "No" 1 "Yes" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define SPOUSE    0 "No" 1 "Yes" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define INLAW     93 "RELATION INDICATED, NO COUNT RECORDED"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define OWNCHILD  93 "RELATION INDICATED, NO COUNT RECORDED"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define STEPCHLD  93 "RELATION INDICATED, NO COUNT RECORDED"
                       97 "REFUSED" 98 "BLANK" 99 "LEGITIMATE SKIP" ;
label define BROSIS    93 "RELATION INDICATED, NO COUNT RECORDED"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define OTHREL    93 "RELATION INDICATED, NO COUNT RECORDED"
                       97 "REFUSED" 98 "BLANK" 99 "LEGITIMATE SKIP" ;
label define FRIENDS   93 "RELATION INDICATED, NO COUNT RECORDED"
                       97 "REFUSED" 98 "BLANK" 99 "LEGITIMATE SKIP" ;
label define OTHERNON  93 "RELATION INDICATED, NO COUNT RECORDED"
                       97 "REFUSED" 98 "BLANK" 99 "LEGITIMATE SKIP" ;
label define SERVICE   1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP (IRAGE<17)" ;
label define MILSTAT   1 "On extended active duty in the Armed Forces"
                       2 "In a Reserves component"
                       3 "Separated/retired from Reserves or active duty"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP (IRAGE<17 or SERVICE=2)" ;
label define MOVDAWAY  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK" ;
label define DORM      94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (MOVDAWAY=2)" ;
label define MILBASE   94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (MOVDAWAY=2)" ;
label define HOSP      94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (MOVDAWAY=2)" ;
label define TELNO     94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MOVES     94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INCOME    1 "No personal earnings" 2 "Yearly under $5,000"
                       3 "Yearly $5,000 to $6,999"
                       4 "Yearly $7,000 to $8,999"
                       5 "Yearly $9,000 to $11,999"
                       6 "Yearly $12,000 to $14,999"
                       7 "Yearly $15,000 to $19,999"
                       8 "Yearly $20,000 to $24,999"
                       9 "Yearly $25,000 to $29,999"
                       10 "Yearly $30,000 to $39,999"
                       11 "Yearly $40,000 to $49,999"
                       12 "Yearly $50,000 to $74,999"
                       13 "Yearly more than $75,000"
                       85 "BAD DATA Log. assgnd" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK" 99 "LEGITIMATE SKIP (IRAGE<15)" ;
label define WKSWORKD  94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WKSFP     1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define TOTFAMIN  1 "No family income" 2 "Yearly Under $5,000"
                       3 "Yearly $5,000 to $6,999"
                       4 "Yearly $7,000 to $8,999"
                       5 "Yearly $9,000 to $11,999"
                       6 "Yearly $12,000 to $14,999"
                       7 "Yearly $15,000 to $19,999"
                       8 "Yearly $20,000 to $24,999"
                       9 "Yearly $25,000 to $29,999"
                       10 "Yearly $30,000 to $39,999"
                       11 "Yearly $40,000 to $49,999"
                       12 "Yearly $50,000 to $74,999"
                       13 "Yearly $75,000 or More" 85 "BAD DATA Log. assgnd"
                       94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK(NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WAGES     1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define SELFEMPL  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define INTDIV    1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define SOCSEC    1 "Yes" 2 "No" 94 "DONT KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK" 99 "LEGITIMATE SKIP" ;
label define SSI       1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define DISABLTY  1 "Yes" 2 "No" 94 "DONT KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK" 99 "LEGITIMATE SKIP" ;
label define OTHRETIR  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define WELFARE   1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define OTHSOURC  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED" 98 "BLANK"
                       99 "LEGITIMATE SKIP" ;
label define AMTWAGES  999992 "ILLEGIBLE" 999994 "DONT KNOW"
                       999995 "BAD DATA" 999997 "REFUSED"
                       999998 "BLANK (No Answer)" 999999 "LEGITIMATE SKIP" ;
label define AMTSELFE  999994 "DONT KNOW" 999995 "BAD DATA" 999997 "REFUSED"
                       999998 "BLANK (No Answer)" 999999 "LEGITIMATE SKIP" ;
label define AMTINTDV  999994 "DONT KNOW" 999995 "BAD DATA" 999997 "REFUSED"
                       999998 "BLANK" 999999 "LEGITIMATE SKIP" ;
label define AMTSOSEC  999994 "DONT KNOW" 999995 "BAD DATA" 999997 "REFUSED"
                       999998 "BLANK (No Answer)" 999999 "LEGITIMATE SKIP" ;
label define AMTSSI    999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (No Answer)" 999999 "LEGITIMATE SKIP" ;
label define AMTDISAB  999994 "DONT KNOW" 999997 "REFUSED" 999998 "BLANK"
                       999999 "LEGITIMATE SKIP" ;
label define AMTOTRET  999994 "DONT KNOW" 999995 "BAD DATA" 999997 "REFUSED"
                       999998 "BLANK" 999999 "LEGITIMATE SKIP" ;
label define AMTWLFAR  999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (No Answer)" 999999 "LEGITIMATE SKIP" ;
label define AMTOTSRC  999994 "DONT KNOW" 999997 "REFUSED" 999998 "BLANK"
                       999999 "LEGITIMATE SKIP" ;
label define BAP       1 "AM" 2 "PM" ;
label define EAP       1 "AM" 2 "PM" 96 "MULTIPLE RESPONSE"
                       98 "BLANK (NO ANSWER)" ;
label define LANGVER   1 "English" 2 "Spanish" ;
label define UNDINT    1 "No difficulty-no language/reading problem"
                       2 "Just a little difficulty-almost no lang/reading problem"
                       3 "Fair amount of difficulty-some lang/reading problem"
                       4 "A lot of difficulty-considerable lang/reading problem"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define COOPINT   1 "Very cooperative" 2 "Fairly cooperative"
                       3 "Not very cooperative" 4 "Openly hostile"
                       98 "BLANK (NO ANSWER)" ;
label define PRIVACY   1 "Completely private-no one present/able to overhear"
                       3 "Minor distractions"
                       5 "Person(s) in room or listening 1/3 of the time"
                       7 "Serious interruptions more than half the time"
                       9 "Constant presence of other person(s)"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define PPRES     1 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define SPRES     2 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define PARPRES   3 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define OARPRES   4 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define OAPRES    5 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define CPRES     6 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define OPRESSPA  2 "Spouse" 3 "Live-in partner,fiancee" 4 "Mother"
                       16 "Daughter" 17 "Son" 18 "Sister" 19 "Brother"
                       20 "Grandmother" 21 "Grandfather"
                       22 "Other female blood relative" 24 "Mother-in-law"
                       28 "Close female friend" 29 "Close male friend"
                       30 "Other female acquaintance, roommate"
                       31 "Other male acquaintance, roommate"
                       40 "Friend (sex unspecified)" 42 "Granparents"
                       43 "Guardian (sex unspecified)"
                       44 "Foster mother, female guardian"
                       46 "Governess, nanny or live-in babysitter"
                       48 "Housekeeper or maid" 50 "Multiple people listed"
                       51 "Relative, sex not specified"
                       52 "Roommate, sex not specified"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define OPRESSPB  18 "Sister" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define OPRESNSP  7 "Response circled" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define POPDEN    1 "1,000,000 or more persons in the SMSA"
                       2 "50,000 to 999,999 persons in the SMSA"
                       3 "Not in the SMSA" ;
label define POPDEN2   1 "1,000,000 or more persons in the SMSA"
                       2 "250,000 to 999,999 persons in the SMSA"
                       3 "Fewer than 250,000 persons in the SMSA"
                       4 "Not in an SMSA and not in a rural area"
                       5 "Not in an SMSA and in a rural area" ;
label define DC        1 "Segment in the Low SES portion of the DC MSA"
                       2 "Segment in the remainder of the DC MSA"
                       9 "Segment not in the DC MSA" ;
label define CENCTY
                       1 "Segment is in the DC MSA and Wash, DC, the Central City"
                       2 "Segment is in the DC MSA but not in Wash, DC, Central City"
                       3 "Segment not within the DC MSA" ;
label define URBARE    1 "Segment in the DC MSA and in the DC Urbanized Area"
                       2 "Segment in the DC MSA but not in the DC Urbanized Area"
                       3 "Not in the DC MSA" ;
label define REGION    1 "Northeast" 2 "North Central" 3 "South" 4 "West" ;
label define DIVISION  1 "New England" 2 "Middle Atlantic"
                       3 "East North Central" 4 "West North Central"
                       5 "South Atlantic" 6 "East South Central"
                       7 "West South Central" 8 "Mountain" 9 "Pacific" ;
label define HSPHCONC  1 "Equal to or greater than 50% Hispanic households"
                       2 "10% or more but less than 50% Hispanic households"
                       3 "Less than 10% Hispanic households" ;
label define HSPPCONC  1 "Equal to or greater than 50% Hispanic persons"
                       2 "10% or more but less than 50% Hispanic persons"
                       3 "Less than 10% Hispanic persons" ;
label define NHBHCONC
                       1 "Equal to or greater than 50% NonHispanic black households"
                       2 "10% or more but less than 50% NonHispanic black households"
                       3 "Less than 10% NonHispanic black households" ;
label define NHBPCONC
                       1 "Equal to or greater than 50% NonHispanic black persons"
                       2 "10% or more but less than 50% Nonhispanic black persons"
                       3 "Less than 10% NonHispanic black persons" ;
label define OWNOCONC
                       1 "Equal to or greater than 50% Owner Occupied Housing Units"
                       2 "10% or more but less than 50% Owner Occupied Housing Units"
                       3 "Less than 10% Owner Occupied Housing Units" ;
label define IIAGE     1 "Age taken from birthdate"
                       2 "Age taken from questionnaire"
                       3 "Age taken from screener" 4 "Age imputed" ;
label define IRSEX     1 "Male" 2 "Female" ;
label define IISEX     1 "Sex taken from questionnaire"
                       2 "Sex taken from screener" ;
label define IRRACE    1 "American Indian or Alaskan Native"
                       2 "Asian or Pacific Islander" 3 "Black" 4 "White" ;
label define IIRACE    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRHOIND   1 "Hispanic" 2 "Not Hispanic" ;
label define IIHOIND   1 "Hispanic Origin taken from questionnaire"
                       2 "Hispanic Origin logically imputed"
                       3 "Statistically imputed data" ;
label define IRHOGRP   1 "Puerto Rican" 2 "Mexican" 3 "Cuban" 4 "Other"
                       99 "LEGITIMATE SKIP" ;
label define IIHOGRP   1 "Hispanic-Origin Group taken from questionnaire"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRMARIT   1 "Married" 2 "Widowed" 3 "Divorced or Separated"
                       4 "Never Married" 99 "LEGITIMATE SKIP" ;
label define IIMARIT   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IREDUC    0 "No schooling" 1 "First grade" 2 "Second grade"
                       3 "Third grade" 4 "Fourth grade" 5 "Fifth grade"
                       6 "Sixth grade" 7 "Seventh grade" 8 "Eighth grade"
                       9 "Ninth grade" 10 "Tenth grade" 11 "Eleventh grade"
                       12 "Twelfth grade" 13 "One year of college"
                       14 "Two years of college" 15 "Three years of college"
                       16 "Four years of college"
                       17 "Graduate/professional school" ;
label define IIEDUC    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRHSGRAD  1 "Yes, graduated from high school"
                       2 "No, did not graduate from high school" ;
label define IIHSGRAD  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRWORKST  1 "Working full-time, 35 hours or more a week"
                       2 "Working part-time, less than 35 hours a week"
                       3 "Have job but out: illness/leave/furlough"
                       4 "Unemployed or laid off and looking for work"
                       5 "Unemployed and not looking for work"
                       6 "Full-time homemaker only" 7 "In school only"
                       8 "Retired" 9 "Disabled, not able to work"
                       10 "Other, in labor force"
                       11 "Other, not in labor force" ;
label define IIWORKST  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRINSUR   1 "Yes, respondent does have health insurance"
                       2 "No, respondent does not have health insurance" ;
label define IIINSUR   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IREARN    1 "No personal earnings" 2 "Yearly under $5,000"
                       3 "Yearly $5,000 to $6,999"
                       4 "Yearly $7,000 to $8,999"
                       5 "Yearly $9,000 to $11,999"
                       6 "Yearly $12,000 to $14,999"
                       7 "Yearly $15,000 to $19,999"
                       8 "Yearly $20,000 to $24,999"
                       9 "Yearly $25,000 to $29,999"
                       10 "Yearly $30,000 to $39,999"
                       11 "Yearly $40,000 to $49,999"
                       12 "Yearly $50,000 to $74,999"
                       13 "Yearly more than $75,000" 99 "LEGITIMATE SKIP" ;
label define IIEARN    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRINC47   1 "No personal earnings" 2 "Yearly under $5,000"
                       3 "Yearly $5,000 to $6,999"
                       4 "Yearly $7,000 to $8,999"
                       5 "Yearly $9,000 to $11,999"
                       6 "Yearly $12,000 to $14,999"
                       7 "Yearly $15,000 to $19,999"
                       8 "Yearly $20,000 to $24,999"
                       9 "Yearly $25,000 to $29,999"
                       10 "Yearly $30,000 to $39,999"
                       11 "Yearly $40,000 to $49,999"
                       12 "Yearly $50,000 to $74,999"
                       13 "Yearly more than $75,000" 99 "LEGITIMATE SKIP" ;
label define IIINC47   1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC48A  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IIINC48A  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC49A  999999 "LEGITIMATE SKIP" ;
label define IIINC49A  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC48B  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IIINC48B  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC49B  999999 "LEGITIMATE SKIP" ;
label define IIINC49B  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC48C  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IIINC48C  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC49C  999999 "LEGITIMATE SKIP" ;
label define IIINC49C  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC48D  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IIINC48D  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC49D  999999 "LEGITIMATE SKIP" ;
label define IIINC49D  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC48E  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IIINC48E  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC49E  999999 "LEGITIMATE SKIP" ;
label define IIINC49E  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC48F  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IIINC48F  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC49F  999999 "LEGITIMATE SKIP" ;
label define IIINC49F  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC48G  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IIINC48G  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC49G  999999 "LEGITIMATE SKIP" ;
label define IIINC49G  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC48H  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP" ;
label define IIINC48H  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC49H  999999 "LEGITIMATE SKIP" ;
label define IIINC49H  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC48I  1 "Yes" 2 "No" 999999 "LEGITIMATE SKIP" ;
label define IIINC48I  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRINC49I  999999 "LEGITIMATE SKIP" ;
label define IIINC49I  1 "Questionnaire data" 2 "Logically imputed"
                       3 "Statistically imputed" 9 "LEGITIMATE SKIP" ;
label define IRALCRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but < 6 months ago"
                       3 "6+ months ago but < 1 year ago"
                       4 "1+ years ago but < 3 years ago" 5 "3+ years ago"
                       9 "Never used alcohol" ;
label define IIALCRC   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRMJRC    1 "Within the past week (7 days)"
                       2 "More than 1 week ago but < 1 month ago"
                       3 "1+ months ago but < 6 months ago"
                       4 "6+ months ago but < 1 year ago"
                       5 "1+ years ago but < 3 years ago" 6 "3+ years ago"
                       9 "Never used marijuana" ;
label define IIMJRC    1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRCOCRC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but < 1 month ago"
                       3 "1+ months ago but < 6 months ago"
                       4 "6+ months ago but < 1 year ago"
                       5 "1+ years ago but < 3 years ago" 6 "3+ years ago"
                       9 "Never used cocaine" ;
label define IICOCRC   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRSEDRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but < 6 months ago"
                       3 "6+ months ago but < 1 year ago"
                       4 "1+ years ago but < 3 years ago" 5 "3+ years ago"
                       9 "Never used sedatives" ;
label define IISEDRC   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRTRNRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but < 6 months ago"
                       3 "6+ months ago but < 1 year ago"
                       4 "1+ years ago but < 3 years ago" 5 "3+ years ago"
                       9 "Never used tranquilizers" ;
label define IITRNRC   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRSTMRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but < 6 months ago"
                       3 "6+ months ago but < 1 year ago"
                       4 "1+ years ago but < 3 years ago" 5 "3+ years ago"
                       9 "Never used stimulants" ;
label define IISTMRC   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRANLRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but < 6 months ago"
                       3 "6+ months ago but < 1 year ago"
                       4 "1+ years ago but < 3 years ago" 5 "3+ years ago"
                       9 "Never used analgesics" ;
label define IIANLRC   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRCIGRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but < 6 months ago"
                       3 "6+ months ago but < 1 year ago"
                       4 "1+ years ago but < 3 years ago" 5 "3+ years ago"
                       9 "Never smoked cigarettes" ;
label define IICIGRC   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IROTBRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but < 6 months ago"
                       3 "6+ months ago but < 1 year ago"
                       4 "1+ years ago but < 3 years ago" 5 "3+ years ago"
                       9 "Never used smokeless tobacco" ;
label define IIOTBRC   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRINHRC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but < 1 month ago"
                       3 "1+ months ago but < 6 months ago"
                       4 "6+ months ago but < 1 year ago"
                       5 "1+ years ago but < 3 years ago" 6 "3+ years ago"
                       9 "Never used inhalants" ;
label define IIINHRC   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRCRKRC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but < 1 month ago"
                       3 "1+ months ago but < 6 months ago"
                       4 "6+ months ago but < 1 year ago"
                       5 "1+ years ago but < 3 years ago" 6 "3+ years ago"
                       9 "Never used crack" ;
label define IICRKRC   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRHALRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but < 6 months ago"
                       3 "6+ months ago but < 1 year ago"
                       4 "1+ years ago but < 3 years ago" 5 "3+ years ago"
                       9 "Never used hallucinogens" ;
label define IIHALRC   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRHERRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but < 6 months ago"
                       3 "6+ months ago but < 1 year ago"
                       4 "1+ years ago but < 3 years ago" 5 "3+ years ago"
                       9 "Never used heroin" ;
label define IIHERRC   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRPCPRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but < 6 months ago"
                       3 "6+ months ago but < 1 year ago"
                       4 "1+ years ago but < 3 years ago" 5 "3+ years ago"
                       9 "Never used PCP" ;
label define IIPCPRC   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRICERC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but < 1 month ago"
                       3 "1+ months ago but < 6 months ago"
                       4 "6+ months ago but < 1 year ago" 6 "3+ years ago"
                       9 "Never used ice" ;
label define IIICERC   1 "Questionnaire data" 2 "Statistically Imputed data" ;
label define IRALCFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IIALCFQ   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRMJFQ    1 "Used several times per day in past year"
                       2 "Used daily in past year"
                       3 "Used almost daily in past year"
                       4 "Used 1-2 days per week in past year"
                       5 "Used several times per month in past year"
                       6 "Used 1-2 times per month in past year"
                       7 "Used every other month in past year"
                       8 "Used 3-5 times in past year"
                       9 "Used 1-2 times in past year"
                       10 "Never used or did not use in the past year" ;
label define IIMJFQ    1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRCOCFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times per month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IICOCFQ   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRSEDFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IISEDFQ   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRTRNFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IITRNFQ   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRSTMFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IISTMFQ   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRANLFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IIANLFQ   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IROTBFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IIOTBFQ   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRINHFQ   1 "Use daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IIINHFQ   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define IRHALFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IIHALFQ   1 "Questionnaire data" 2 "Statistically imputed data" ;
label define CATAGE    1 "12-17 years (IRAGE = 12-17)"
                       2 "18-25 years (IRAGE = 18-25)"
                       3 "26-34 years (IRAGE = 26-34)"
                       4 "35+ years (IRAGE > 34)" ;
label define CATAG2    1 "12-17 years (CATAGE = 1)"
                       2 "18-25 years (CATAGE = 2)"
                       3 "26+ years (CATAGE = 3-4)" ;
label define RACE      1 "White (IRRACE = 4 and IRHOIND = 2)"
                       2 "Black (IRRACE = 3 and IRHOIND = 2)"
                       3 "Hispanic (IRHOIND = 1)"
                       4 "Other (IRRACE = 1-2 and IRHOIND = 2)" ;
label define EDUCCAT2  1 "Less than high school (IREDUC=0-11 and I"
                       2 "High school graduate (IREDUC = 12 and IR"
                       3 "Some college (IREDUC = 13-15 and IRAGE ="
                       4 "College graduate (IREDUC = 16-17 and IRA"
                       5 "12-17 year olds (IRAGE = 12-17)" ;
label define EMPSTAT2  1 "Full-time (IRWORKST = 1,3 and IRAGE => 1"
                       2 "Part-time (IRWORKST = 2 and IRAGE => 18)"
                       3 "Unemployed (IRWORKST = 4,5,10 and IRAGE"
                       4 "Other (IRWORKST = 6-9,11 and IRAGE => 18"
                       5 "12-17 year olds (IRAGE = 12-17)" ;
label define TOTINC    9999999 "LEGITIMATE SKIP" ;
label define TOTCAT    1 "No personal earnings" 2 "Yearly under $5,000"
                       3 "Yearly $5,000 to $6,999"
                       4 "Yearly $7,000 to $8,999"
                       5 "Yearly $9,000 to $11,999"
                       6 "Yearly $12,000 to $14,999"
                       7 "Yearly $15,000 to $19,999"
                       8 "Yearly $20,000 to $24,999"
                       9 "Yearly $25,000 to $29,999"
                       10 "Yearly $30,000 to $39,999"
                       11 "Yearly $40,000 to $49,999"
                       12 "Yearly $50,000 to $74,999"
                       13 "Yearly more than $75,000" 99 "LEGITIMATE SKIP" ;
label define FAMINC    1 "Yearly $0 to $8,999 (TOTCAT = 1-4)"
                       2 "Yearly $9,000 to $19,999 (TOTCAT = 5-7)"
                       3 "Yearly $20,000 to $39,999 (TOTCAT = 8-10"
                       4 "Yearly $40,000 to 74,999 (TOTCAT = 11-1"
                       5 "Yearly more than $75,000 (TOTCAT = 13)"
                       6 "LEGITIMATE SKIP (TOTCAT = 99)" ;
label define PEREARN   1 "No personal earnings (IREARN = 1)"
                       2 "Yearly under $5,000 to $8,999 (IREARN ="
                       3 "Yearly $9,000 to $19,999 (IREARN = 5-7)"
                       4 "Yearly $20,000 to 39,999 (IREARN = 8-10)"
                       5 "Yearly more than $40,000 (IREARN = 11-13"
                       6 "LEGITIMATE SKIP (IRAGE < 18)" ;
label define HALFLAG   0 "Never used (IRHALRC = 9)"
                       1 "Ever used (IRHALRC = 1-5)" ;
label define HALYR     0 "Did not use in the past year (IRHALRC ="
                       1 "Used within the past year (IRHALRC = 1-3" ;
label define HALMON    0 "Did not use in the past month (IRHALRC ="
                       1 "Used within the past month (IRHALRC = 1)" ;
label define PCPFLAG   0 "Never used (IRPCPRC = 9)"
                       1 "Ever used (IRPCPRC = 1,5)" ;
label define PCPYR     0 "Did not use in the past year (IRPCPRC ="
                       1 "Used within the past year (IRPCPRC = 1-3" ;
label define PCPMON    0 "Did not use in the past month (IRPCPRC ="
                       1 "Used within the past month (IRPCPRC = 1)" ;
label define STMFLAG   0 "Never used (IRSTMRC = 9)"
                       1 "Ever used (IRSTMRC = 1-5)" ;
label define STMYR     0 "Did not use in the past year (IRSTMRC ="
                       1 "Used within the past year (IRSTMRC = 1-3" ;
label define STMMON    0 "Did not use in the past month (IRSTMRC ="
                       1 "Used within the past month (IRSTMRC = 1)" ;
label define SEDFLAG   0 "Never used (IRSEDRC = 9)"
                       1 "Ever used (IRSEDRC = 1-5)" ;
label define SEDYR     0 "Did not use in the past year (IRSEDRC ="
                       1 "Used within the past year (IRSEDRC = 1-3" ;
label define SEDMON    0 "Did not use in the past month (IRSEDRC ="
                       1 "Used within the past month (IRSEDRC = 1)" ;
label define TRQFLAG   0 "Never used (IRTRNRC = 9)"
                       1 "Ever used (IRTRNRC = 1-5)" ;
label define TRQYR     0 "Did not use in the past year (IRTRNRC ="
                       1 "Used within the past year (IRTRNRC = 1-3" ;
label define TRQMON    0 "Did not use in the past month (IRTRNRC ="
                       1 "Used within the past month (IRTRNRC = 1)" ;
label define ANLFLAG   0 "Never used (IRANLRC = 9)"
                       1 "Ever used (IRANLRC = 1-5)" ;
label define ANLYR     0 "Did not use in the past year (IRANLRC ="
                       1 "Used within the past year (IRANLRC = 1-3" ;
label define ANLMON    0 "Did not use in the past month (IRANLRC ="
                       1 "Used within the past month (IRANLRC = 1)" ;
label define ALCFLAG   0 "Never used (IRALCRC = 9)"
                       1 "Ever used (IRALCRC = 1-5)" ;
label define ALCYR     0 "Did not use in the past year (IRALCRC ="
                       1 "Used within the past year (IRALCRC = 1-3" ;
label define ALCMON    0 "Did not use in the past month (IRALCRC ="
                       1 "Used within the past month (IRALCRC = 1)" ;
label define CIGFLAG   0 "Never used (IRCIGRC = 9)"
                       1 "Ever used (IRCIGRC = 1-5)" ;
label define CIGYR     0 "Did not use in the past year (IRCIGRC ="
                       1 "Used within the past year (IRCIGRC = 1-3" ;
label define CIGMON    0 "Did not use in the past month (IRCIGRC ="
                       1 "Used within the past month (IRCIGRC = 1)" ;
label define SMKFLAG   0 "Never used (IROTBRC = 9)"
                       1 "Ever used (IROTBRC = 1-5)" ;
label define SMKYR     0 "Did not use in the past year (IROTBRC ="
                       1 "Used within the past year (IROTBRC = 1-3" ;
label define SMKMON    0 "Did not use in the past month (IROTBRC ="
                       1 "Used within the past month (IROTBRC = 1)" ;
label define HERFLAG   0 "Never used (IRHERRC = 9)"
                       1 "Ever used (IRHERRC = 1-5)" ;
label define HERYR     0 "Did not use in the past year (IRHERRC ="
                       1 "Used within the past year (IRHERRC = 1-3" ;
label define HERMON    0 "Did not use in the past month (IRHERRC ="
                       1 "Used within the past month (IRHERRC = 1)" ;
label define MRJFLAG   0 "Never used (IRMJRC = 9)"
                       1 "Ever used (IRMJRC = 1-6)" ;
label define MRJYR     0 "Did not use in the past year (IRMJRC = 5"
                       1 "Used within the past year (IRMJRC = 1-4)" ;
label define MRJMON    0 "Did not use in the past month (IRMJRC ="
                       1 "Used within the past month (IRMJRC = 1-2" ;
label define COCFLAG   0 "Never used (IRCOCRC = 9)"
                       1 "Ever used (IRCOCRC = 1-6)" ;
label define COCYR     0 "Did not use in the past year (IRCOCRC ="
                       1 "Used within the past year (IRCOCRC = 1-4" ;
label define COCMON    0 "Did not use in the past month (IRCOCRC ="
                       1 "Used within the past month (IRCOCRC = 1-" ;
label define CRKFLAG   0 "Never used (IRCRKRC = 9)"
                       1 "Ever used (IRCRKRC = 1-6)" ;
label define CRKYR     0 "Did not use in the past year (IRCRKCR= 5"
                       1 "Used within the past year (IRCRKRC = 1-4" ;
label define CRKMON    0 "Did not use in the past month (IRCRKRC ="
                       1 "Used within the past month (IRCRKRC = 1-" ;
label define INHFLAG   0 "Never used (IRINHRC = 9)"
                       1 "Ever used (IRINHRC = 1-6)" ;
label define INHYR     0 "Did not use in the past year (IRINHRC ="
                       1 "Used within the past year (IRINHRC = 1-4" ;
label define INHMON    0 "Did not use in the past month (IRINHRC ="
                       1 "Used within the past month (IRINHRC = 1-" ;
label define NEEDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED A NEEDLE TO INJECT ANY DRUG"
                       98 "NEEDLE USE NOT INDICATED BUT 1+ SOURCE" ;
label define NDL90REC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED A NEEDLE TO INJECT ANY DRUG"
                       98 "NEEDLE USE NOT INDICATED BUT 1+ SOURCE" ;
label define NDL90RC2  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED A NEEDLE TO INJECT ANY DRUG"
                       91 "NEVER USED A NEEDLE TO INJECT ANY DRUG"
                       98 "NEEDLE USE NOT INDICATED BUT 1+ SOURCE" ;
label define NEDFLAG2  0 "Never used (NDL90REC = 91,98)"
                       1 "Ever used (NDL90REC = 1-9)" ;
label define NEDYR2    0 "Did not use in the past year (NDL90REC=4"
                       1 "Used within the past year (NDL90REC=1-3," ;
label define HALYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRHALFQ=1-" ;
label define HALMONF   0 "Did not use monthly/more past year (IRHA"
                       1 "Used monthly or more often past year (IR" ;
label define HALWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRH" ;
label define STMYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRSTMFQ=1-" ;
label define STMMONF   0 "Did not use monthly/more past year (IRST"
                       1 "Used monthly or more often past year (IR" ;
label define STMWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRS" ;
label define SEDYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRSEDFQ=1-" ;
label define SEDMONF   0 "Did not use monthly/more past year (IRSE"
                       1 "Used monthly or more often past year (IR" ;
label define SEDWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRS" ;
label define TRQYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRTRNFQ=1-" ;
label define TRQMONF   0 "Did not use monthly/more past year (IRTR"
                       1 "Used monthly or more often past year (IR" ;
label define TRQWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRT" ;
label define ANLYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRANLFQ=1-" ;
label define ANLMONF   0 "Did not use monthly/more past year (IRAN"
                       1 "Used monthly or more often past year (IR" ;
label define ANLWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRA" ;
label define ALCYRF    0 "Never used or not used in past year (IRA"
                       1 "Any use within the past year (IRALCFQ=1-" ;
label define ALCMONF   0 "Did not use monthly/more past year (IRAL"
                       1 "Used monthly or more often past year (IR" ;
label define ALCWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more in past year (IRALCF" ;
label define SMKYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IROTBFQ=1-" ;
label define SMKMONF   0 "Did not use monthly/more past year (IROT"
                       1 "Used monthly or more often past year (IR" ;
label define SMKWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRO" ;
label define MRJYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRMJFQ=1-9" ;
label define MRJMONF   0 "Did not use monthly/more past year (IRMJ"
                       1 "Used monthly or more in past year (IRMJF" ;
label define MRJWKF    0 "Did not use weekly/more past year (IRMJF"
                       1 "Used weekly or more in past year (IRMJFQ" ;
label define COCYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRCOCFQ =" ;
label define COCMONF   0 "Did not use monthly/more past year (IRCO"
                       1 "Used monthly or more often past year (IR" ;
label define COCWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRC" ;
label define INHYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRINHFQ=1-" ;
label define INHMONF   0 "Did not use monthly/more past year (IRIN"
                       1 "Used monthly or more often past year (IR" ;
label define INHWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRI" ;
label define PSYFLAG2  0 "Never used (ALL SOURCE VARIABLES = 9)"
                       1 "Ever used (ANY SOURCE VARIABLE < 9)" ;
label define PSYYR2    0 "Did not use within past year (ALL SOURCE"
                       1 "Used in past year (ANY SOURCE VARIABLE <" ;
label define PSYMON2   0 "Did not use in past month (ALL SOURCE VA"
                       1 "Used in past month (ANY SOURCE VARIABLE" ;
label define SUMFLAG   0 "Never used (ALL SOURCE VARIABLES = 0)"
                       1 "Ever used (ANY SOURCE VARIABLE = 1)" ;
label define SUMYR     0 "Did not use in past year (ALL SOURCE VAR"
                       1 "Used in past year (ANY SOURCE VARIABLE =" ;
label define SUMMON    0 "Did not use in past month (ALL SOURCE VA"
                       1 "Used in past month (ANY SOURCE VARIABLE" ;
label define MJOFLAG
                       0 "Never used MJ/has used both MJ & another illict drug"
                       1 "Marijuana is only (illicit) drug ever used" ;
label define MJOYR2    0 "MJ not used past yr/Used MJ & othr drug past yr"
                       1 "Marijuana is only (illicit) drug in past year" ;
label define MJOMON2   0 "MJ not used past mnth/Used MJ & othr drug past mo"
                       1 "Marijuana only (illicit) drug in past month" ;
label define AEROS2    0 "Never inhaled (AEROS = 2,81,91,98)"
                       1 "Ever inhaled (AEROS = 1,3)" ;
label define ALCDAYS2  1 "None or never used alcohol (ALCDAYS = 0,"
                       2 "1-2 days (ALCDAYS = 1-2)"
                       3 "3-4 days (ALCDAYS = 3-4)"
                       4 "5-19 days (ALCDAYS = 5-19)"
                       5 "20-30 days (ALCDAYS = 20-30)" ;
label define ALCDAYS3  1 "None or never used alcohol (ALCDAYS2 = 1"
                       2 "1-4 days (ALCDAYS2 = 2-3)"
                       3 "5-19 days (ALCDAYS2 = 4)"
                       4 "20-30 days (ALCDAYS2 = 5)" ;
label define ALCMON2   1 "Did not use in the past month (ALCMON ="
                       2 "Used within the past month (ALCMON = 1)" ;
label define AMYLNIT2  0 "Never inhaled (AMYLNIT = 2,81,91,98)"
                       1 "Ever inhaled (AMYLNIT = 1,3)" ;
label define AVCIG2    1 "None or never smoked cigarettes (AVCIG=8"
                       2 "Currently smoke < a pack per day (AVCIG"
                       3 "Currently smoke a pack or more per day (" ;
label define AVCIG3    0 "None/never/< pack a day (AVCIG=1-3,81,89"
                       1 "Currently smoke a pack or more per day (" ;
label define CIGMON2   1 "Did not use in past month (CIGMON = 0)"
                       2 "Used within past month (CIGMON = 1)" ;
label define CLEFLU2   0 "Never inhaled (CLEFLU = 2,81,91,98)"
                       1 "Ever inhaled (CLEFLU = 1,3)" ;
label define COCIV2    0 "Never/no use in pst 12 mos (COCIV=2,81,8"
                       1 "Injected in the past 12 months (COCIV =" ;
label define COCNEWA2  0 "Never/no use in pst 12 mos (COCNEWA=81,8"
                       1 "Used other ways past 12 months (COCNEWA" ;
label define COCSNIF2  0 "Never/no use pst 12 mos(COCSNIFF=2,81,83"
                       1 "Sniffed/snorted in past 12 months (COCSN" ;
label define COCSWAL2  0 "Never/no use pst 12 mos(COCSWAL=2,81,83,"
                       1 "Swallowed/drank in past 12 months (COCSW" ;
label define COCTOT2   1 "Never used cocaine (COCTOT = 81,91)"
                       2 "1-2 times (COCTOT = 1)"
                       3 "3-10 times (COCTOT = 2,3)"
                       4 "11-99 times (COCTOT = 4,5)"
                       5 "100 or more times (COCTOT = 6,7)"
                       6 "Unknown (COCTOT = 85,98)" ;
label define COCTOT3   1 "1-2 times (COCTOT2 = 2)"
                       2 "3-10 times (COCTOT2 = 3)"
                       3 "11-99 times (COCTOT2 = 4)"
                       4 "100 or more times (COCTOT2 = 5)"
                       5 "Never used cocaine (COCTOT2 = 1)" ;
label define DCOTSMSA  1 "DC MSA (DC=1,2)"
                       2 "Large SMSAs not including DC (POPDEN=1 a" 3 "Other" ;
label define DRINKER2  0 "Never/no alcohol use (ALCMON=0 and DR5DA"
                       1 "Alcohol use (ALCMON = 1 and DR5DAY = 0-3" ;
label define DRUNKYR2  0 "Unknown (DRUNKYR = 85,96,97,98)"
                       1 "Drunk more than twice a month (DRUNKYR ="
                       2 "Drunk twice a month or less (DRUNKYR = 5"
                       3 "Never drunk in past year (DRUNKYR = 9)" ;
label define ETHER2    0 "Never inhaled (ETHER = 2,81,91,98)"
                       1 "Ever inhaled (ETHER = 1,3)" ;
label define FREEBAS2  0 "Never/no use pst 12 mos (FREEBASE=2,81,8"
                       1 "Freebased in past 12 months (FREEBASE =" ;
label define GAS2      0 "Never inhaled (GAS = 2,81,91,98)"
                       1 "Ever inhaled (GAS = 1,3)" ;
label define GLUE2     0 "Never inhaled (GLUE = 2,81,91,98)"
                       1 "Ever inhaled (GLUE = 1,3)" ;
label define GNDLSHR2  0 "No (GNNDLSHR=2,81,91,98)" 1 "Yes (GNNDLSHR=1)" ;
label define HVYDRK2   0 "Never/no heavy use (DR5DAY=0-4,81,91)"
                       1 "Heavy alcohol use (DR5DAY = 5-30)" ;
label define LSD2      0 "Never used hallucinogens (LSD = 2,81,91,"
                       1 "Ever used LSD (LSD = 1)" ;
label define MESC2     0 "Never used hallucinogens (MESC = 2,81,91"
                       1 "Ever used Mescaline (MESC = 1)" ;
label define MJDY30A2  1 "None or never used marijuana (MJDAY30A ="
                       2 "1-2 days (MJDAY30A = 1-2)"
                       3 "3-4 days (MJDAY30A = 3-4)"
                       4 "5-19 days (MJDAY30A = 5-19)"
                       5 "20-30 days (MJDAY30A = 20-30)"
                       6 "Unknown (MJDAY30A = 85,98)" ;
label define MJDY30A3  1 "1-2 days (MJDAY30A2 = 2)"
                       2 "3-4 days (MJDAY30A2 = 3)"
                       3 "5-19 days (MJDAY30A2 = 4)"
                       4 "20-30 days (MJDAY30A2 = 5)"
                       5 "None or never used marijuana (MJDAY30A2" ;
label define MJTOT2    1 "Never used marijuana (MJTOT = 81,91)"
                       2 "1-2 times (MJTOT = 1)" 3 "3-10 times (MJTOT = 2,3)"
                       4 "11-99 times (MJTOT = 4,5)"
                       5 "100 or more times (MJTOT = 6,7)"
                       6 "Unknown (MJTOT = 85,96,97,98)" ;
label define MJTOT3    1 "1-2 times (MJTOT2 = 2)" 2 "3-10 times (MJTOT2 = 3)"
                       3 "11-99 times (MJTOT2 = 4)"
                       4 "100 or more times (MJTOT2 = 5)"
                       5 "Never used marijuana (MJTOT2 = 1)" ;
label define MRJMON2   1 "Did not use in past month (MRJMON = 0)"
                       2 "Used within the past month (MRJMON = 1)" ;
label define NEDFLAG3  0 "Never used (NDL90RC2=81,91,98)"
                       1 "Ever used (NDL90RCC2=1-9)" ;
label define NITOXID2  0 "Never inhaled (NITOXID = 2,81,91,98)"
                       1 "Ever inhaled (NITOXID = 1,3)" ;
label define NOTMARJ   0 "No (ALL SOURCE VARIABLES = 0)"
                       1 "Yes (ANY SOURCE VARIABLES = 1)" ;
label define PEYOTE2   0 "Never used hallucinogens (PEYOTE = 2,81,"
                       1 "Ever used Peyote (PEYOTE = 1)" ;
label define PSILCY2   0 "Never used hallucinogens (PSILCY = 2,81,"
                       1 "Ever used Psilocybin (PSILCY = 1)" ;
label define RACESEX   1 "White male (SEX = 1 and RACE = 1)"
                       2 "Black male (SEX = 1 and RACE = 2)"
                       3 "Hispanic male (SEX = 1 and RACE = 3)"
                       4 "White female (SEX = 2 and RACE = 1)"
                       5 "Black female (SEX = 2 and RACE = 2)"
                       6 "Hispanic female (SEX = 2 and RACE = 3)" ;
label define SOLVENT2  0 "Never inhaled (SOLVENT = 2,81,91,98)"
                       1 "Ever inhaled (SOLVENT = 1,3)" ;
label define SPPAINT2  0 "Never inhaled (SPPAINT = 2,81,91,98)"
                       1 "Ever inhaled (SPPAINT = 1,3)" ;
label define IRAS13    1 "Never used any of the substances listed"
                       2 "Used one or more of the listed substance" ;
label define IRDEP     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRDEP1    112 "Restoril"
                       116 "Methaqualone (including Sopor, Quaalude)"
                       120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       121 "USED SEDATIVE, DONT KNOW NAME" 123 "Unisom"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       332 "Ephedrine" 339 "Amphetamines (speed)"
                       348 "Crystal" 401 "Darvon"
                       501 "Gasoline or lighter fluids"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       808 "All of the ones Ive tried" 812 "Cigars"
                       813 "Cigarettes, Tobacco" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IRDEP2    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       201 "Valium" 209 "Xanax" 332 "Ephedrine"
                       336 "Diet pills" 420 "OTHER Analgesic, NOT SPECIFIED"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 999 "LEGITIMATE SKIP" ;
label define IRDEP3    221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (Speed or Crank)"
                       409 "Tylenol with Codeine"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRDEP4    807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRARG     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRARG1    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       123 "Unisom" 209 "Xanax"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       332 "Ephedrine" 336 "Diet pills" 348 "Crystal"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, Felt-tip pens"
                       601 "LSD (acid, white lightning)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       812 "Cigars" 813 "Cigarettes, Tobacco"
                       816 "Smokeless tobacco - snuff/chewing" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IRARG2    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       201 "Valium"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       325 "USED STIMULANT, DONT KNOW NAME" 336 "Diet pills"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       813 "Cigarettes, Tobacco" 999 "LEGITIMATE SKIP" ;
label define IRARG3    201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       409 "Tylenol with Codeine" 803 "Marijuana"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRALN     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRALN1    116 "Methaqualone (including Sopor, Quaalude)"
                       120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       121 "USED SEDATIVE, DONT KNOW NAME" 123 "Unisom"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       332 "Ephedrine" 510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       813 "Cigarettes, Tobacco" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IRALN2    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       336 "Diet pills" 510 "OTHER Inhalant, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, Tobacco"
                       999 "LEGITIMATE SKIP" ;
label define IRALN3    221 "OTHER Tranquilizer, NOT SPECIFIED"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       999 "LEGITIMATE SKIP" ;
label define IRANX     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRANX1    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       122 "Sleep Aid" 201 "Valium" 209 "Xanax"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       325 "USED STIMULANT, DONT KNOW NAME"
                       329 "Speckled Eggs, Robins Eggs" 332 "Ephedrine"
                       336 "Diet pills" 339 "Amphetamines (speed)"
                       348 "Crystal" 510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, Felt-tip pens" 513 "Tulio Osica"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       808 "All of the ones Ive tried" 812 "Cigars"
                       813 "Cigarettes, Tobacco" 814 "Caffeine" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IRANX2    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       325 "USED STIMULANT, DONT KNOW NAME" 336 "Diet pills"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       605 "PCP (angel dust, phencyclidine)" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 999 "LEGITIMATE SKIP" ;
label define IRANX3    221 "OTHER Tranquilizer, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)" 803 "Marijuana"
                       807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRHLT     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRHLT1    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       325 "USED STIMULANT, DONT KNOW NAME"
                       339 "Amphetamine (speed)" 348 "Crystal" 426 "Fiorinal"
                       430 "Aspirin, Ecotrine" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       812 "Cigars" 813 "Cigarettes, Tobacco" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IRHLT2    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol" 813 "Cigarettes, Tobacco"
                       999 "LEGITIMATE SKIP" ;
label define IRHLT3    221 "OTHER Tranquilizer, NOT SPECIFIED" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 999 "LEGITIMATE SKIP" ;
label define IRNTK     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRNTK1    116 "Methaqualone (including Sopor, Quaalude)"
                       120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       122 "Sleep Aid" 201 "Valium" 209 "Xanax"
                       222 "USED TRANQUILIZER, DONT KNOW NAME"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       348 "Crystal" 510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, Felt-tip pens"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       812 "Cigars" 813 "Cigarettes, Tobacco" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IRNTK2    24 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       409 "Tylenol with Codeine" 417 "Morphine"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 999 "LEGITIMATE SKIP" ;
label define IRNTK3    221 "OTHER Tranquilizer, NOT SPECIFIED"
                       603 "Mescaline" 605 "PCP (angel dust, phencyclidine)"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRNTK4    803 "Marijuana" 999 "LEGITIMATE SKIP" ;
label define IRUPS     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRUPS1    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       122 "Sleep Aid" 201 "Valium"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       325 "USED STIMULANT, DONT KNOW NAME" 332 "Ephedrine"
                       336 "Diet pills" 348 "Crystal"
                       409 "Tylenol with Codeine"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, Felt-tip pens"
                       601 "LSD (acid, white lightning)"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       813 "Cigarettes, Tobacco" 814 "Caffeine" 815 "Coffee"
                       817 "Hardstuff" 998 "BLANK" 999 "LEGITIMATE SKIP" ;
label define IRUPS2    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       336 "Diet pills" 420 "OTHER Analgesic, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, Tobacco"
                       999 "LEGITIMATE SKIP" ;
label define IRUPS3    221 "OTHER Tranquilizer, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRLSW     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRLSW1    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       201 "Valium" 222 "USED TRANQUILIZER, DONT KNOW NAME"
                       322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       325 "USED STIMULANT, DONT KNOW NAME" 348 "Crystal"
                       409 "Tylenol with Codeine"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       808 "All of the ones Ive tried"
                       813 "Cigarettes, Tobacco" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IRLSW2    201 "Valium"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       601 "LSD (acid, white lightning)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 999 "LEGITIMATE SKIP" ;
label define IRLSW3    803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRSSP     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRSSP1    116 "Methaqualone (including Sopor, Quaalude)"
                       120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       122 "Sleep Aid" 322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       348 "Crystal" 353 "No-Doz"
                       511 "Markers, Felt-tip pens"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       808 "All of the ones Ive tried"
                       813 "Cigarettes, Tobacco" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IRSSP2    702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       807 "Alcohol" 813 "Cigarettes, Tobacco"
                       999 "LEGITIMATE SKIP" ;
label define IRSSP3    803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRCPE     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRCPE1    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       122 "Sleep Aid" 322 "Methamphetamine (Speed or Crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       348 "Crystal" 426 "Fiorinal"
                       510 "OTHER Inhalant, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       808 "All of the ones Ive tried"
                       813 "Cigarettes, Tobacco1" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IRCPE2    201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol" 813 "Cigarettes, Tobacco"
                       999 "LEGITIMATE SKIP" ;
label define IRCPE3    803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IREMG     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IREMG1    603 "Mescaline" 702 "Heroin" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, Tobacco" 998 "BLANK"
                       999 "LEGITIMATE SKIP" ;
label define IREMG2    803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IREMG3    806 "Crack" 807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IREMG4    601 "LSD (acid, white lightning)"
                       999 "LEGITIMATE SKIP" ;
label define ANYPROB   0 "No" 1 "Yes" ;
label define TWOPROB   0 "No" 1 "Yes" ;
label define THREPROB  0 "No" 1 "Yes" ;
label define ALNALC2   0 "No" 1 "Yes" ;
label define ALNCIG2   0 "No" 1 "Yes" ;
label define ALNCOC2   0 "No" 1 "Yes" ;
label define ALNMRJ2   0 "No" 1 "Yes" ;
label define ANXALC2   0 "No" 1 "Yes" ;
label define ANXCIG2   0 "No" 1 "Yes" ;
label define ANXCOC2   0 "No" 1 "Yes" ;
label define ANXMRJ2   0 "No" 1 "Yes" ;
label define ARGALC2   0 "No" 1 "Yes" ;
label define ARGCIG2   0 "No" 1 "Yes" ;
label define ARGCOC2   0 "No" 1 "Yes" ;
label define ARGMRJ2   0 "No" 1 "Yes" ;
label define CPEALC2   0 "No" 1 "Yes" ;
label define CPECIG2   0 "No" 1 "Yes" ;
label define CPECOC2   0 "No" 1 "Yes" ;
label define CPEMRJ2   0 "No" 1 "Yes" ;
label define DEPALC2   0 "No" 1 "Yes" ;
label define DEPCIG2   0 "No" 1 "Yes" ;
label define DEPCOC2   0 "No" 1 "Yes" ;
label define DEPMRJ2   0 "No" 1 "Yes" ;
label define EMALC2    0 "No" 1 "Yes" ;
label define EMCIG2    0 "No" 1 "Yes" ;
label define EMCOC2    0 "No" 1 "Yes" ;
label define EMMRJ2    0 "No" 1 "Yes" ;
label define HLTALC2   0 "No" 1 "Yes" ;
label define HLTCIG2   0 "No" 1 "Yes" ;
label define HLTCOC2   0 "No" 1 "Yes" ;
label define HLTMRJ2   0 "No" 1 "Yes" ;
label define LSWALC2   0 "No" 1 "Yes" ;
label define LSWCIG2   0 "No" 1 "Yes" ;
label define LSWCOC2   0 "No" 1 "Yes" ;
label define LSWMRJ2   0 "No" 1 "Yes" ;
label define NTKALC2   0 "No" 1 "Yes" ;
label define NTKCIG2   0 "No" 1 "Yes" ;
label define NTKCOC2   0 "No" 1 "Yes" ;
label define NTKMRJ2   0 "No" 1 "Yes" ;
label define SSPALC2   0 "No" 1 "Yes" ;
label define SSPCIG2   0 "No" 1 "Yes" ;
label define SSPCOC2   0 "No" 1 "Yes" ;
label define SSPMRJ2   0 "No" 1 "Yes" ;
label define UPSALC2   0 "No" 1 "Yes" ;
label define UPSCIG2   0 "No" 1 "Yes" ;
label define UPSCOC2   0 "No" 1 "Yes" ;
label define UPSMRJ2   0 "No" 1 "Yes" ;
label define PRB1ALC   0 "No" 1 "Yes" ;
label define PRB1CIG   0 "No" 1 "Yes" ;
label define PRB1COC   0 "No" 1 "Yes" ;
label define PRB1MRJ   0 "No" 1 "Yes" ;
label define PRB2ALC   0 "No" 1 "Yes" ;
label define PRB2CIG   0 "No" 1 "Yes" ;
label define PRB2COC   0 "No" 1 "Yes" ;
label define PRB2MRJ   0 "No" 1 "Yes" ;
label define PRB3ALC   0 "No" 1 "Yes" ;
label define PRB3CIG   0 "No" 1 "Yes" ;
label define PRB3COC   0 "No" 1 "Yes" ;
label define PRB3MRJ   0 "No" 1 "Yes" ;
label define IRCDALC   1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in past year"
                       99 "LEGITIMATE SKIP" ;
label define IRCDCIG   1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in past year"
                       99 "LEGITIMATE SKIP" ;
label define IRCDCOC   1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in past year"
                       99 "LEGITIMATE SKIP" ;
label define IRCDMJ    1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in past year"
                       99 "LEGITIMATE SKIP" ;
label define IREFALC   1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for same effect"
                       99 "LEGITIMATE SKIP" ;
label define IREFCIG   1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for same effect"
                       99 "LEGITIMATE SKIP" ;
label define IREFCOC   1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for same effect"
                       99 "LEGITIMATE SKIP" ;
label define IREFMJ    1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for same effect"
                       99 "LEGITIMATE SKIP" ;
label define IRUDALC   1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past year"
                       99 "LEGITIMATE SKIP" ;
label define IRUDCIG   1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past year"
                       99 "LEGITIMATE SKIP" ;
label define IRUDCOC   1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past year"
                       99 "LEGITIMATE SKIP" ;
label define IRUDMJ    1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past year"
                       99 "LEGITIMATE SKIP" ;
label define IRDPALC   1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug used past year"
                       99 "LEGITIMATE SKIP" ;
label define IRDPCIG   1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug used past year"
                       99 "LEGITIMATE SKIP" ;
label define IRDPCOC   1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug used past year"
                       99 "LEGITIMATE SKIP" ;
label define IRDPMJ    1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug used past year"
                       99 "LEGITIMATE SKIP" ;
label define IRWSALC   1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the past year"
                       99 "LEGITIMATE SKIP" ;
label define IRWSCIG   1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the past year"
                       99 "LEGITIMATE SKIP" ;
label define IRWSCOC   1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the past year"
                       99 "LEGITIMATE SKIP" ;
label define IRWSMJ    1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the past year"
                       99 "LEGITIMATE SKIP" ;
label define ALCPROBS  0 "No" 1 "Yes" ;
label define CIGPROBS  0 "No" 1 "Yes" ;
label define COCPROBS  0 "No" 1 "Yes" ;
label define MJPROBS   0 "No" 1 "Yes" ;
label define IRNOBOOZ  1 "No use of alcohol in the past year"
                       2 "Used alcohol in the past year" ;
label define IRALCABS  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCAGG  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCALO  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCARG  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCBRK  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCDRU  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCFRD  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCHIG  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCHOL  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCINT  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCJOB  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCMAT  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCMOR  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCQUI  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCREL  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCREM  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCSHO  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCTOS  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define ANYALC    0 "No" 1 "Yes" ;
label define THREALC   0 "No" 1 "Yes" ;
label define ALCONLYL  0 "No" 1 "Yes (ALCFLAG=1 AND SUMFLAG=0)" ;
label define ALCONLYY  0 "No" 1 "Yes (ALCYR=1 AND SUMYR=0)" ;
label define ALCONLYM  0 "No" 1 "Yes (ALCMON=1 AND SUMMON=0)" ;
label define ILLONLYL  0 "No" 1 "Yes (SUMFLAG=1 AND ALCFLAG=0)" ;
label define ILLONLYY  0 "No" 1 "Yes (SUMYR=1 AND ALCYR=0)" ;
label define ILLONLYM  0 "No" 1 "Yes (SUMMON=1 AND ALCMON=0)" ;
label define MRJONLYL  0 "No" 1 "Yes (MJOFLAG=1 AND ALCFLAG=0)" ;
label define MRJONLYY  0 "No" 1 "Yes (MJOYR2=1 AND ALCYR=0)" ;
label define MRJONLYM  0 "No" 1 "Yes (MJOMON2=1 AND ALCMON=0)" ;
label define PSYONLYL  0 "No" 1 "Yes (PSYFLAG2=1 & ALL OTHER SOURCE VAR" ;
label define PSYONLYY  0 "No" 1 "Yes (PSYYR2=1 & ALL OTHER SOURCE VARS=" ;
label define PSYONLYM  0 "No" 1 "Yes (PSYMON2=1 & ALL OTHER SOURCE VARS" ;
label define OTHONLYL  0 "No" 1 "Yes (1ST 3 SRCE VAR=0 & ANY OTHR SRCE" ;
label define OTHONLYY  0 "No" 1 "Yes (1ST 3 SRCE VAR=0 & ANY OTHR SRCE" ;
label define OTHONLYM  0 "No" 1 "Yes (1ST 3 SRCE VAR=0 & ANY OTHR SRCE" ;
label define ALCILLL   0 "No" 1 "Yes (ALCFLAG=1 AND SUMFLAG=1)" ;
label define ALCILLY   0 "No" 1 "Yes (ALCYR=1 AND SUMYR=1)" ;
label define ALCILLM   0 "No" 1 "Yes (ALCMON=1 AND SUMMON=1)" ;
label define ALCMRJL   0 "No" 1 "Yes (ALCFLAG,MRJFLAG=1& ALLOTHRSRCE VAR" ;
label define ALCMRJY   0 "No" 1 "Yes (ALCYR AND MRJYR=1& ALLOTHRSRCE VAR" ;
label define ALCMRJM   0 "No" 1 "Yes (ALCMON & MRJMON=1& ALLOTHRSRCEVA" ;
label define ALCPSYL   0 "No" 1 "Yes (ALCFLAG,PSYFLAG2=1& ALLOTHRSRCEVAR" ;
label define ALCPSYY   0 "No" 1 "Yes (ALCYR & PSYYR2=1& ALLOTHRSRCE VA" ;
label define ALCPSYM   0 "No" 1 "Yes (ALCMON& PSYMON2=1& ALLOTHRSRCEVAR" ;
label define ALCOTHL   0 "No" 1 "Yes (ALCFLAG=1& NEXT 2VAR=0& ANYOTHRVA" ;
label define ALCOTHY   0 "No" 1 "Yes (ALCYR=1 & NEXT 2VAR=0 & ANY OTH" ;
label define ALCOTHM   0 "No" 1 "Yes (ALCMON=1& NEXT 2VAR=0& ANY OTHR V" ;
label define SUB1LIF   0 "No" 1 "Yes (ONLY ONE OF THE SOURCE VARS=1)" ;
label define SUB1YR    0 "No" 1 "Yes (ONLY ONE OF THE SOURCE VARS=1)" ;
label define SUB1MON   0 "No" 1 "Yes (ONLY ONE OF THE SOURCE VARS=1)" ;
label define SUB2LIF   0 "No" 1 "Yes (ONLY TWO OF THE SOURCE VARS=1)" ;
label define SUB2YR    0 "No" 1 "Yes (ONLY TWO OF THE SOURCE VARS=1)" ;
label define SUB2MON   0 "No" 1 "Yes (ONLY TWO OF THE SOURCE VARS=1)" ;
label define SUB3LIF   0 "No" 1 "Yes (THREE OR MORE OF THE SOURCE VARS=1)" ;
label define SUB3YR    0 "No" 1 "Yes (THREE OR MORE OF THE SOURCE VARS=1)" ;
label define SUB3MON   0 "No" 1 "Yes (THREE OR MORE OF THE SOURCE VARS=1)" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.\n
****************************************************************/

/*
replace CIGTRY = . if (CIGTRY >= 81 )
replace CIG5PK = . if (CIG5PK >= 13 )
replace CIGAGE = . if (CIGAGE >= 81 )
replace CIGYRS = . if (CIGYRS >= 81 )
replace PACKS = . if (PACKS >= 13 )
replace CIGREC = . if (CIGREC >= 13 )
replace AVCIG = . if (AVCIG >= 13 )
replace CIGTIME = . if (CIGTIME >= 989 )
replace SNUFREC = . if (SNUFREC >= 13 )
replace OTHTOB = . if (OTHTOB >= 13 )
replace ALCTRY = . if (ALCTRY >= 81 )
replace ALCREC = . if (ALCREC >= 13 )
replace ALCAGE = . if (ALCAGE >= 81 )
replace ALCDAYS = . if (ALCDAYS >= 81 )
replace NODR30A = . if (NODR30A >= 81 )
replace DR5DAY = . if (DR5DAY >= 81 )
replace MODR30A = . if (MODR30A >= 81 )
replace MODR30DY = . if (MODR30DY >= 81 )
replace ALCPAT = . if (ALCPAT >= 13 )
replace DRUNKYR = . if (DRUNKYR >= 13 )
replace ALCSED = . if (ALCSED >= 13 )
replace ALCTRAN = . if (ALCTRAN >= 13 )
replace ALCSTM = . if (ALCSTM >= 13 )
replace ALCANAL = . if (ALCANAL >= 13 )
replace ALCMJ = . if (ALCMJ >= 13 )
replace ALCINH = . if (ALCINH >= 13 )
replace ALCCOC = . if (ALCCOC >= 13 )
replace ALCHAL = . if (ALCHAL >= 13 )
replace ALCOPT = . if (ALCOPT >= 13 )
replace ALCNONE = . if (ALCNONE >= 13 )
replace ALCPREF = . if (ALCPREF >= 13 )
replace NOSEDAT = . if (NOSEDAT >= 13 )
replace BUTISOL = . if (BUTISOL >= 13 )
replace BUTICAPS = . if (BUTICAPS >= 13 )
replace AMYTAL = . if (AMYTAL >= 13 )
replace MEBARAL = . if (MEBARAL >= 13 )
replace PLACIDYL = . if (PLACIDYL >= 13 )
replace DORIDEN = . if (DORIDEN >= 13 )
replace NOLUDAR = . if (NOLUDAR >= 13 )
replace NEMBUTAL = . if (NEMBUTAL >= 13 )
replace SECONAL = . if (SECONAL >= 13 )
replace TUINAL = . if (TUINAL >= 13 )
replace DALMANE = . if (DALMANE >= 13 )
replace RESTORIL = . if (RESTORIL >= 13 )
replace HALCION = . if (HALCION >= 13 )
replace AMOBARB = . if (AMOBARB >= 13 )
replace PHENOBAR = . if (PHENOBAR >= 13 )
replace METHAQ = . if (METHAQ >= 13 )
replace CHHYD = . if (CHHYD >= 13 )
replace PENTOB = . if (PENTOB >= 13 )
replace SECOB = . if (SECOB >= 13 )
replace SEDNEWA = . if (SEDNEWA >= 991 )
replace SEDNEWB = . if (SEDNEWB >= 991 )
replace SEDNEWC = . if (SEDNEWC >= 991 )
replace SEDNOSP = . if (SEDNOSP >= 13 )
replace SEDDKNAM = . if (SEDDKNAM >= 13 )
replace SEDAGE = . if (SEDAGE >= 81 )
replace SEDTOT = . if (SEDTOT >= 13 )
replace SEDREC = . if (SEDREC >= 13 )
replace SEDYRFRQ = . if (SEDYRFRQ >= 13 )
replace AS3READ = . if (AS3READ >= 13 )
replace NOTRANQ = . if (NOTRANQ >= 13 )
replace VALIUM = . if (VALIUM >= 13 )
replace LIBRIUM = . if (LIBRIUM >= 13 )
replace LIMBTROL = . if (LIMBTROL >= 13 )
replace MENRIUM = . if (MENRIUM >= 13 )
replace SERAX = . if (SERAX >= 13 )
replace TRANXENE = . if (TRANXENE >= 13 )
replace ATIVAN = . if (ATIVAN >= 13 )
replace CENTRAX = . if (CENTRAX >= 13 )
replace XANAX = . if (XANAX >= 13 )
replace PAXIPAM = . if (PAXIPAM >= 13 )
replace BUSPAR = . if (BUSPAR >= 13 )
replace MILTOWN = . if (MILTOWN >= 13 )
replace EQUANIL = . if (EQUANIL >= 13 )
replace DEPROL = . if (DEPROL >= 13 )
replace VISTAR = . if (VISTAR >= 13 )
replace ATARAX = . if (ATARAX >= 13 )
replace DURRAX = . if (DURRAX >= 13 )
replace DIAZEPAM = . if (DIAZEPAM >= 13 )
replace SKLY = . if (SKLY >= 13 )
replace MEPROB = . if (MEPROB >= 13 )
replace TRNEWA = . if (TRNEWA >= 991 )
replace TRNEWB = . if (TRNEWB >= 991 )
replace TRNEWC = . if (TRNEWC >= 991 )
replace TRNOSP = . if (TRNOSP >= 13 )
replace TRDKNAM = . if (TRDKNAM >= 13 )
replace TRANAGE = . if (TRANAGE >= 81 )
replace TRANTOT = . if (TRANTOT >= 13 )
replace TRANREC = . if (TRANREC >= 13 )
replace TRNYRFRQ = . if (TRNYRFRQ >= 13 )
replace AS4READ = . if (AS4READ >= 13 )
replace NOSTIMS = . if (NOSTIMS >= 13 )
replace DEXED = . if (DEXED >= 13 )
replace DEXAMYL = . if (DEXAMYL >= 13 )
replace ESKAT = . if (ESKAT >= 13 )
replace BENZ = . if (BENZ >= 13 )
replace BIPHET = . if (BIPHET >= 13 )
replace DESOXYN = . if (DESOXYN >= 13 )
replace TENUATE = . if (TENUATE >= 13 )
replace TEPANIL = . if (TEPANIL >= 13 )
replace DIDREX = . if (DIDREX >= 13 )
replace PLEGINE = . if (PLEGINE >= 13 )
replace PRELUDIN = . if (PRELUDIN >= 13 )
replace IONAMIN = . if (IONAMIN >= 13 )
replace FASTIN = . if (FASTIN >= 13 )
replace PONDIMIN = . if (PONDIMIN >= 13 )
replace VORANIL = . if (VORANIL >= 13 )
replace SANOREX = . if (SANOREX >= 13 )
replace MAZANOR = . if (MAZANOR >= 13 )
replace RITALIN = . if (RITALIN >= 13 )
replace CYLERT = . if (CYLERT >= 13 )
replace DETAMP = . if (DETAMP >= 13 )
replace METHI = . if (METHI >= 13 )
replace METHAMP = . if (METHAMP >= 13 )
replace OBLA = . if (OBLA >= 13 )
replace STIMNEWA = . if (STIMNEWA >= 991 )
replace STIMNEWB = . if (STIMNEWB >= 991 )
replace STIMNEWC = . if (STIMNEWC >= 991 )
replace STIMNEWD = . if (STIMNEWD >= 991 )
replace STIMNOSP = . if (STIMNOSP >= 13 )
replace STMDKNAM = . if (STMDKNAM >= 13 )
replace STIMAGE = . if (STIMAGE >= 81 )
replace STIMTOT = . if (STIMTOT >= 13 )
replace STIMREC = . if (STIMREC >= 13 )
replace STMYRFRQ = . if (STMYRFRQ >= 13 )
replace STNEEDLE = . if (STNEEDLE >= 13 )
replace STNDLREC = . if (STNDLREC >= 13 )
replace AS5READ = . if (AS5READ >= 13 )
replace ANALNONE = . if (ANALNONE >= 13 )
replace DARVON = . if (DARVON >= 13 )
replace DOLENE = . if (DOLENE >= 13 )
replace SK65A = . if (SK65A >= 13 )
replace WYGESIC = . if (WYGESIC >= 13 )
replace LEVODRO = . if (LEVODRO >= 13 )
replace PERCODAN = . if (PERCODAN >= 13 )
replace DEMEROL = . if (DEMEROL >= 13 )
replace DILAUD = . if (DILAUD >= 13 )
replace TYLCOD = . if (TYLCOD >= 13 )
replace PHENCOD = . if (PHENCOD >= 13 )
replace TALWIN = . if (TALWIN >= 13 )
replace TALWINNX = . if (TALWINNX >= 13 )
replace TALACEN = . if (TALACEN >= 13 )
replace PROPOXY = . if (PROPOXY >= 13 )
replace CODEINE = . if (CODEINE >= 13 )
replace ANILERID = . if (ANILERID >= 13 )
replace MORPHINE = . if (MORPHINE >= 13 )
replace METHDON = . if (METHDON >= 13 )
replace STADOL = . if (STADOL >= 13 )
replace ANALNEWA = . if (ANALNEWA >= 991 )
replace ANALNEWB = . if (ANALNEWB >= 991 )
replace ANALNEWC = . if (ANALNEWC >= 991 )
replace ANLNOSP = . if (ANLNOSP >= 13 )
replace ANLDKNAM = . if (ANLDKNAM >= 13 )
replace ANALAGE = . if (ANALAGE >= 81 )
replace ANALTOT = . if (ANALTOT >= 13 )
replace ANALREC = . if (ANALREC >= 13 )
replace ANLYRFRQ = . if (ANLYRFRQ >= 13 )
replace MJOPP = . if (MJOPP >= 81 )
replace MJAGE = . if (MJAGE >= 81 )
replace MJTOT = . if (MJTOT >= 13 )
replace MJREC = . if (MJREC >= 13 )
replace MJDAY30A = . if (MJDAY30A >= 81 )
replace MJAV30A = . if (MJAV30A >= 81 )
replace MJAMT30A = . if (MJAMT30A >= 81 )
replace MJYRFREQ = . if (MJYRFREQ >= 13 )
replace MJJOINT = . if (MJJOINT >= 13 )
replace MJPIPE = . if (MJPIPE >= 13 )
replace MJBAKE = . if (MJBAKE >= 13 )
replace MJCHEW = . if (MJCHEW >= 13 )
replace MJNEWA = . if (MJNEWA >= 81 )
replace MJNOSP = . if (MJNOSP >= 13 )
replace AS7READ = . if (AS7READ >= 13 )
replace GAS = . if (GAS >= 13 )
replace SPPAINT = . if (SPPAINT >= 13 )
replace AEROS = . if (AEROS >= 13 )
replace GLUE = . if (GLUE >= 13 )
replace SOLVENT = . if (SOLVENT >= 13 )
replace AMYLNIT = . if (AMYLNIT >= 13 )
replace ETHER = . if (ETHER >= 13 )
replace NITOXID = . if (NITOXID >= 13 )
replace CLEFLU = . if (CLEFLU >= 13 )
replace INHNEWA = . if (INHNEWA >= 991 )
replace INHNEWB = . if (INHNEWB >= 991 )
replace INHNOSP = . if (INHNOSP >= 13 )
replace INHDKNAM = . if (INHDKNAM >= 13 )
replace INHAGE = . if (INHAGE >= 81 )
replace INHTOT = . if (INHTOT >= 13 )
replace INHREC = . if (INHREC >= 13 )
replace INHYRFRQ = . if (INHYRFRQ >= 13 )
replace GAS30A = . if (GAS30A >= 13 )
replace SPPAN30A = . if (SPPAN30A >= 13 )
replace AEROS30A = . if (AEROS30A >= 13 )
replace GLUE30A = . if (GLUE30A >= 13 )
replace SOLVN30A = . if (SOLVN30A >= 13 )
replace AMLNT30A = . if (AMLNT30A >= 13 )
replace ETHER30A = . if (ETHER30A >= 13 )
replace NOX30A = . if (NOX30A >= 13 )
replace CLFL30A = . if (CLFL30A >= 13 )
replace INNEW30A = . if (INNEW30A >= 991 )
replace INNEW30B = . if (INNEW30B >= 991 )
replace IN30NOSP = . if (IN30NOSP >= 13 )
replace INH30NO = . if (INH30NO >= 13 )
replace INHDY30A = . if (INHDY30A >= 81 )
replace INHEFF = . if (INHEFF >= 13 )
replace INHPO = . if (INHPO >= 13 )
replace INHQNC1 = . if (INHQNC1 >= 13 )
replace INHQNC2 = . if (INHQNC2 >= 13 )
replace INHQNC3 = . if (INHQNC3 >= 13 )
replace INHQNC4 = . if (INHQNC4 >= 13 )
replace INHQNC5 = . if (INHQNC5 >= 13 )
replace INHQNC6 = . if (INHQNC6 >= 13 )
replace INHQNC7 = . if (INHQNC7 >= 13 )
replace INHQNC8 = . if (INHQNC8 >= 13 )
replace INHQNC9 = . if (INHQNC9 >= 13 )
replace INHQNC10 = . if (INHQNC10 >= 13 )
replace INHANSY = . if (INHANSY >= 13 )
replace COCOPP = . if (COCOPP >= 81 )
replace COCAGE = . if (COCAGE >= 81 )
replace COCTOT = . if (COCTOT >= 13 )
replace COCREC = . if (COCREC >= 13 )
replace COCUS30A = . if (COCUS30A >= 81 )
replace COCYRFRQ = . if (COCYRFRQ >= 13 )
replace COCSNIFF = . if (COCSNIFF >= 13 )
replace COCSWAL = . if (COCSWAL >= 13 )
replace COCIV = . if (COCIV >= 13 )
replace FREEBASE = . if (FREEBASE >= 13 )
replace COCNEWA = . if (COCNEWA >= 13 )
replace COCNEWB = . if (COCNEWB >= 13 )
replace COCNOSP = . if (COCNOSP >= 13 )
replace CONDLREC = . if (CONDLREC >= 13 )
replace CRAKREC = . if (CRAKREC >= 13 )
replace CRKAM30A = . if (CRKAM30A >= 981 )
replace CRAKBUCK = . if (CRAKBUCK >= 9981 )
replace COCAM30A = . if (COCAM30A >= 13 )
replace COCBUCK = . if (COCBUCK >= 9981 )
replace AS9READ = . if (AS9READ >= 13 )
replace LSD = . if (LSD >= 13 )
replace PEYOTE = . if (PEYOTE >= 13 )
replace MESC = . if (MESC >= 13 )
replace PSILCY = . if (PSILCY >= 13 )
replace PCP = . if (PCP >= 13 )
replace ECSTASY = . if (ECSTASY >= 13 )
replace HALNEWA = . if (HALNEWA >= 991 )
replace HALNEWB = . if (HALNEWB >= 991 )
replace HALNOSP = . if (HALNOSP >= 13 )
replace HALDKNAM = . if (HALDKNAM >= 13 )
replace HALLOPP = . if (HALLOPP >= 81 )
replace HALLAGE = . if (HALLAGE >= 81 )
replace HALLTOT = . if (HALLTOT >= 13 )
replace HALLREC = . if (HALLREC >= 13 )
replace HAL30USE = . if (HAL30USE >= 81 )
replace HALYRFRQ = . if (HALYRFRQ >= 13 )
replace PCPREC = . if (PCPREC >= 13 )
replace AS10READ = . if (AS10READ >= 13 )
replace HEROPP = . if (HEROPP >= 81 )
replace HERAGE = . if (HERAGE >= 81 )
replace HERTOT = . if (HERTOT >= 13 )
replace HERREC = . if (HERREC >= 13 )
replace HER30USE = . if (HER30USE >= 81 )
replace HERNEEDL = . if (HERNEEDL >= 13 )
replace HRNDLREC = . if (HRNDLREC >= 13 )
replace AS11READ = . if (AS11READ >= 13 )
replace CDCIG = . if (CDCIG >= 13 )
replace CDALC = . if (CDALC >= 13 )
replace CDSED = . if (CDSED >= 13 )
replace CDTRAN = . if (CDTRAN >= 13 )
replace CDSTM = . if (CDSTM >= 13 )
replace CDANAL = . if (CDANAL >= 13 )
replace CDMJ = . if (CDMJ >= 13 )
replace CDINH = . if (CDINH >= 13 )
replace CDCOC = . if (CDCOC >= 13 )
replace CDHALL = . if (CDHALL >= 13 )
replace CDHER = . if (CDHER >= 13 )
replace CDOTHOP = . if (CDOTHOP >= 13 )
replace CDNONE = . if (CDNONE >= 13 )
replace EFFCIG = . if (EFFCIG >= 13 )
replace EFFALC = . if (EFFALC >= 13 )
replace EFFSED = . if (EFFSED >= 13 )
replace EFFTRAN = . if (EFFTRAN >= 13 )
replace EFFSTM = . if (EFFSTM >= 13 )
replace EFFANAL = . if (EFFANAL >= 13 )
replace EFFMJ = . if (EFFMJ >= 13 )
replace EFFINH = . if (EFFINH >= 13 )
replace EFFCOC = . if (EFFCOC >= 13 )
replace EFFHALL = . if (EFFHALL >= 13 )
replace EFFHER = . if (EFFHER >= 13 )
replace EFFOTHOP = . if (EFFOTHOP >= 13 )
replace EFFNONE = . if (EFFNONE >= 13 )
replace UDAYCIG = . if (UDAYCIG >= 13 )
replace UDAYALC = . if (UDAYALC >= 13 )
replace UDAYSED = . if (UDAYSED >= 13 )
replace UDAYTRAN = . if (UDAYTRAN >= 13 )
replace UDAYSTM = . if (UDAYSTM >= 13 )
replace UDAYANAL = . if (UDAYANAL >= 13 )
replace UDAYMJ = . if (UDAYMJ >= 13 )
replace UDAYINH = . if (UDAYINH >= 13 )
replace UDAYCOC = . if (UDAYCOC >= 13 )
replace UDAYHALL = . if (UDAYHALL >= 13 )
replace UDAYHER = . if (UDAYHER >= 13 )
replace UDAYOTH = . if (UDAYOTH >= 13 )
replace UDAYNONE = . if (UDAYNONE >= 13 )
replace DEPCIG = . if (DEPCIG >= 13 )
replace DEPALC = . if (DEPALC >= 13 )
replace DEPSED = . if (DEPSED >= 13 )
replace DEPTRAN = . if (DEPTRAN >= 13 )
replace DEPSTM = . if (DEPSTM >= 13 )
replace DEPANAL = . if (DEPANAL >= 13 )
replace DEPMJ = . if (DEPMJ >= 13 )
replace DEPINH = . if (DEPINH >= 13 )
replace DEPCOC = . if (DEPCOC >= 13 )
replace DEPHALL = . if (DEPHALL >= 13 )
replace DEPHER = . if (DEPHER >= 13 )
replace DEPOTHOP = . if (DEPOTHOP >= 13 )
replace DEPNONE = . if (DEPNONE >= 13 )
replace WSCIG = . if (WSCIG >= 13 )
replace WSALC = . if (WSALC >= 13 )
replace WSSED = . if (WSSED >= 13 )
replace WSTRAN = . if (WSTRAN >= 13 )
replace WSSTM = . if (WSSTM >= 13 )
replace WSANAL = . if (WSANAL >= 13 )
replace WSMJ = . if (WSMJ >= 13 )
replace WSINH = . if (WSINH >= 13 )
replace WSCOC = . if (WSCOC >= 13 )
replace WSHALL = . if (WSHALL >= 13 )
replace WSHER = . if (WSHER >= 13 )
replace WSOTHOP = . if (WSOTHOP >= 13 )
replace WSNONE = . if (WSNONE >= 13 )
replace ICELIFE = . if (ICELIFE >= 13 )
replace ICEREC = . if (ICEREC >= 13 )
replace AS12READ = . if (AS12READ >= 13 )
replace GNNDLLIF = . if (GNNDLLIF >= 13 )
replace GNNDLREC = . if (GNNDLREC >= 13 )
replace GNNDLSED = . if (GNNDLSED >= 13 )
replace GNNDLTRA = . if (GNNDLTRA >= 13 )
replace GNNDLSTM = . if (GNNDLSTM >= 13 )
replace GNNDLANL = . if (GNNDLANL >= 13 )
replace GNNDLMJ = . if (GNNDLMJ >= 13 )
replace GNNDLINH = . if (GNNDLINH >= 13 )
replace GNNDLCOC = . if (GNNDLCOC >= 13 )
replace GNNDLHAL = . if (GNNDLHAL >= 13 )
replace GNNDLHER = . if (GNNDLHER >= 13 )
replace GNNDLOPT = . if (GNNDLOPT >= 13 )
replace GNNDLNON = . if (GNNDLNON >= 13 )
replace GNNDLSHR = . if (GNNDLSHR >= 13 )
replace AS13READ = . if (AS13READ >= 13 )
replace NOBOOZYR = . if (NOBOOZYR >= 13 )
replace ALCAGGR = . if (ALCAGGR >= 13 )
replace ALCARGUM = . if (ALCARGUM >= 13 )
replace ALCABSNT = . if (ALCABSNT >= 13 )
replace ALCHIGH = . if (ALCHIGH >= 13 )
replace ALCJOB = . if (ALCJOB >= 13 )
replace ALCMATCD = . if (ALCMATCD >= 13 )
replace ALCRELCD = . if (ALCRELCD >= 13 )
replace ALCFRDCD = . if (ALCFRDCD >= 13 )
replace ALCTOSS = . if (ALCTOSS >= 13 )
replace ALCHOLIC = . if (ALCHOLIC >= 13 )
replace ALCDRUNK = . if (ALCDRUNK >= 13 )
replace ALCINTOX = . if (ALCINTOX >= 13 )
replace ALCREM = . if (ALCREM >= 13 )
replace ALCQUICK = . if (ALCQUICK >= 13 )
replace ALCMORN = . if (ALCMORN >= 13 )
replace ALCSHOOK = . if (ALCSHOOK >= 13 )
replace ALCALONE = . if (ALCALONE >= 13 )
replace ALCBRKPM = . if (ALCBRKPM >= 13 )
replace AS13NONE = . if (AS13NONE >= 13 )
replace DRDEPRSS = . if (DRDEPRSS >= 13 )
replace DEPDRG1A = . if (DEPDRG1A >= 900 )
replace DEPDRG2A = . if (DEPDRG2A >= 998 )
replace DEPDRG3A = . if (DEPDRG3A >= 998 )
replace DEPDRG4A = . if (DEPDRG4A >= 998 )
replace DRARGUM = . if (DRARGUM >= 13 )
replace ARGDRG1A = . if (ARGDRG1A >= 900 )
replace ARGDRG2A = . if (ARGDRG2A >= 900 )
replace ARGDRG3A = . if (ARGDRG3A >= 998 )
replace DRALONE = . if (DRALONE >= 13 )
replace ALNDRG1A = . if (ALNDRG1A >= 900 )
replace ALNDRG2A = . if (ALNDRG2A >= 998 )
replace ALNDRG3A = . if (ALNDRG3A >= 998 )
replace DRANX = . if (DRANX >= 97 )
replace ANXDRG1A = . if (ANXDRG1A >= 900 )
replace ANXDRG2A = . if (ANXDRG2A >= 900 )
replace ANXDRG3A = . if (ANXDRG3A >= 900 )
replace DRHEALTH = . if (DRHEALTH >= 13 )
replace HLTDRG1A = . if (HLTDRG1A >= 900 )
replace HLTDRG2A = . if (HLTDRG2A >= 900 )
replace HLTDRG3A = . if (HLTDRG3A >= 998 )
replace DRNTHINK = . if (DRNTHINK >= 97 )
replace NTKDRG1A = . if (NTKDRG1A >= 900 )
replace NTKDRG2A = . if (NTKDRG2A >= 900 )
replace NTKDRG3A = . if (NTKDRG3A >= 998 )
replace NTKDRG4A = . if (NTKDRG4A >= 998 )
replace DRUPSET = . if (DRUPSET >= 97 )
replace UPSDRG1A = . if (UPSDRG1A >= 900 )
replace UPSDRG2A = . if (UPSDRG2A >= 900 )
replace UPSDRG3A = . if (UPSDRG3A >= 998 )
replace DRLSWORK = . if (DRLSWORK >= 96 )
replace LSWDRG1A = . if (LSWDRG1A >= 900 )
replace LSWDRG2A = . if (LSWDRG2A >= 900 )
replace LSWDRG3A = . if (LSWDRG3A >= 998 )
replace DRSUSPIC = . if (DRSUSPIC >= 97 )
replace SSPDRG1A = . if (SSPDRG1A >= 900 )
replace SSPDRG2A = . if (SSPDRG2A >= 900 )
replace SSPDRG3A = . if (SSPDRG3A >= 998 )
replace DRCOPE = . if (DRCOPE >= 97 )
replace CPEDRG1A = . if (CPEDRG1A >= 900 )
replace CPEDRG2A = . if (CPEDRG2A >= 900 )
replace CPEDRG3A = . if (CPEDRG3A >= 998 )
replace DREMGMED = . if (DREMGMED >= 97 )
replace EMDRG1A = . if (EMDRG1A >= 900 )
replace EMDRG2A = . if (EMDRG2A >= 900 )
replace EMDRG3A = . if (EMDRG3A >= 998 )
replace EMDRG4A = . if (EMDRG4A >= 998 )
replace RSKPKCIG = . if (RSKPKCIG >= 94 )
replace RSKTRYMJ = . if (RSKTRYMJ >= 94 )
replace RSKMJOCC = . if (RSKMJOCC >= 94 )
replace RSKMJREG = . if (RSKMJREG >= 94 )
replace RKTRYPCP = . if (RKTRYPCP >= 94 )
replace RKPCPREG = . if (RKPCPREG >= 94 )
replace RKTRYHER = . if (RKTRYHER >= 92 )
replace RKHERREG = . if (RKHERREG >= 94 )
replace RKTRYCOC = . if (RKTRYCOC >= 94 )
replace RKCOCOCC = . if (RKCOCOCC >= 94 )
replace RKCOCREG = . if (RKCOCREG >= 94 )
replace RKCRKOCC = . if (RKCRKOCC >= 94 )
replace RKANSOCC = . if (RKANSOCC >= 94 )
replace RKANSREG = . if (RKANSREG >= 94 )
replace RK2DRINK = . if (RK2DRINK >= 94 )
replace RK5DRINK = . if (RK5DRINK >= 94 )
replace RSKBINGE = . if (RSKBINGE >= 94 )
replace HIGHBP = . if (HIGHBP >= 96 )
replace BPMED = . if (BPMED >= 92 )
replace WALKPAIN = . if (WALKPAIN >= 94 )
replace TIMEPAIN = . if (TIMEPAIN >= 98 )
replace UPSHOR = . if (UPSHOR >= 98 )
replace ASTHMA = . if (ASTHMA >= 92 )
replace TRPSYCH = . if (TRPSYCH >= 92 )
replace HEART = . if (HEART >= 94 )
replace FLU = . if (FLU >= 94 )
replace ALLERG = . if (ALLERG >= 94 )
replace HOSPYR = . if (HOSPYR >= 97 )
replace SOREYR = . if (SOREYR >= 94 )
replace RUNNYYR = . if (RUNNYYR >= 94 )
replace COUGHYR = . if (COUGHYR >= 94 )
replace PHLEGMYR = . if (PHLEGMYR >= 94 )
replace HEALTHYR = . if (HEALTHYR >= 94 )
replace HELTHINS = . if (HELTHINS >= 94 )
replace BIRTHMON = . if (BIRTHMON >= 94 )
replace MARITAL = . if (MARITAL >= 85 )
replace NOMARR = . if (NOMARR >= 85 )
replace WORKSTAT = . if (WORKSTAT >= 96 )
replace PAYMO = . if (PAYMO >= 85 )
replace PAYYR = . if (PAYYR >= 91 )
replace ROCCUP2 = . if (ROCCUP2 >= 990 )
replace BUSINES2 = . if (BUSINES2 >= 990 )
replace SECTOR = . if (SECTOR >= 94 )
replace NO5JOB = . if (NO5JOB >= 94 )
replace WORKDAYS = . if (WORKDAYS >= 94 )
replace WORKBLAH = . if (WORKBLAH >= 85 )
replace CWE = . if (CWE >= 92 )
replace FULLPART = . if (FULLPART >= 94 )
replace CWEOCC2 = . if (CWEOCC2 >= 990 )
replace CWEBUS2 = . if (CWEBUS2 >= 990 )
replace CWESECTR = . if (CWESECTR >= 94 )
replace EDUC = . if (EDUC >= 94 )
replace GRADHS = . if (GRADHS >= 92 )
replace DIPLOMA = . if (DIPLOMA >= 94 )
replace ENROLLD = . if (ENROLLD >= 97 )
replace STUDENT = . if (STUDENT >= 97 )
replace SCHDAYS = . if (SCHDAYS >= 92 )
replace SKIPPED = . if (SKIPPED >= 97 )
replace SCHPLANS = . if (SCHPLANS >= 94 )
replace MILES = . if (MILES >= 99991 )
replace ACCID = . if (ACCID >= 85 )
replace NOCHILD = . if (NOCHILD >= 94 )
replace TOTPEOP = . if (TOTPEOP >= 97 )
replace MOTHER = . if (MOTHER >= 97 )
replace FATHER = . if (FATHER >= 97 )
replace STEPMOM = . if (STEPMOM >= 97 )
replace STEPDAD = . if (STEPDAD >= 97 )
replace SPOUSE = . if (SPOUSE >= 97 )
replace INLAW = . if (INLAW >= 93 )
replace OWNCHILD = . if (OWNCHILD >= 93 )
replace STEPCHLD = . if (STEPCHLD >= 93 )
replace BROSIS = . if (BROSIS >= 93 )
replace OTHREL = . if (OTHREL >= 93 )
replace FRIENDS = . if (FRIENDS >= 93 )
replace OTHERNON = . if (OTHERNON >= 93 )
replace SERVICE = . if (SERVICE >= 97 )
replace MILSTAT = . if (MILSTAT >= 94 )
replace MOVDAWAY = . if (MOVDAWAY >= 94 )
replace DORM = . if (DORM >= 94 )
replace MILBASE = . if (MILBASE >= 94 )
replace HOSP = . if (HOSP >= 94 )
replace TELNO = . if (TELNO >= 13 )
replace MOVES = . if (MOVES >= 94 )
replace INCOME = . if (INCOME >= 85 )
replace WKSWORKD = . if (WKSWORKD >= 94 )
replace WKSFP = . if (WKSFP >= 94 )
replace TOTFAMIN = . if (TOTFAMIN >= 85 )
replace WAGES = . if (WAGES >= 94 )
replace SELFEMPL = . if (SELFEMPL >= 94 )
replace INTDIV = . if (INTDIV >= 94 )
replace SOCSEC = . if (SOCSEC >= 94 )
replace SSI = . if (SSI >= 94 )
replace DISABLTY = . if (DISABLTY >= 94 )
replace OTHRETIR = . if (OTHRETIR >= 94 )
replace WELFARE = . if (WELFARE >= 94 )
replace OTHSOURC = . if (OTHSOURC >= 94 )
replace AMTWAGES = . if (AMTWAGES >= 999992 )
replace AMTSELFE = . if (AMTSELFE >= 999994 )
replace AMTINTDV = . if (AMTINTDV >= 999994 )
replace AMTSOSEC = . if (AMTSOSEC >= 999994 )
replace AMTSSI = . if (AMTSSI >= 999994 )
replace AMTDISAB = . if (AMTDISAB >= 999994 )
replace AMTOTRET = . if (AMTOTRET >= 999994 )
replace AMTWLFAR = . if (AMTWLFAR >= 999994 )
replace AMTOTSRC = . if (AMTOTSRC >= 999994 )
replace UNDINT = . if (UNDINT >= 94 )
replace COOPINT = . if (COOPINT >= 98 )
replace PRIVACY = . if (PRIVACY >= 96 )
replace PPRES = . if (PPRES >= 98 )
replace SPRES = . if (SPRES >= 98 )
replace PARPRES = . if (PARPRES >= 98 )
replace OARPRES = . if (OARPRES >= 98 )
replace OAPRES = . if (OAPRES >= 98 )
replace CPRES = . if (CPRES >= 98 )
replace OPRESSPA = . if (OPRESSPA >= 98 )
replace OPRESSPB = . if (OPRESSPB >= 98 )
replace OPRESNSP = . if (OPRESNSP >= 95 )
replace DC = . if (DC >= 9 )
replace IRHOGRP = . if (IRHOGRP >= 13 )
replace IIHOGRP = . if (IIHOGRP >= 9 )
replace IRMARIT = . if (IRMARIT >= 99 )
replace IIMARIT = . if (IIMARIT >= 9 )
replace IRWORKST = . if (IRWORKST >= 13 )
replace IREARN = . if (IREARN >= 99 )
replace IIEARN = . if (IIEARN >= 9 )
replace IRINC47 = . if (IRINC47 >= 99 )
replace IIINC47 = . if (IIINC47 >= 9 )
replace IRINC48A = . if (IRINC48A >= 99 )
replace IIINC48A = . if (IIINC48A >= 9 )
replace IRINC49A = . if (IRINC49A >= 999999 )
replace IIINC49A = . if (IIINC49A >= 9 )
replace IRINC48B = . if (IRINC48B >= 99 )
replace IIINC48B = . if (IIINC48B >= 9 )
replace IRINC49B = . if (IRINC49B >= 999999 )
replace IIINC49B = . if (IIINC49B >= 9 )
replace IRINC48C = . if (IRINC48C >= 99 )
replace IIINC48C = . if (IIINC48C >= 9 )
replace IRINC49C = . if (IRINC49C >= 999999 )
replace IIINC49C = . if (IIINC49C >= 9 )
replace IRINC48D = . if (IRINC48D >= 99 )
replace IIINC48D = . if (IIINC48D >= 9 )
replace IRINC49D = . if (IRINC49D >= 999999 )
replace IIINC49D = . if (IIINC49D >= 9 )
replace IRINC48E = . if (IRINC48E >= 99 )
replace IIINC48E = . if (IIINC48E >= 9 )
replace IRINC49E = . if (IRINC49E >= 999999 )
replace IIINC49E = . if (IIINC49E >= 9 )
replace IRINC48F = . if (IRINC48F >= 99 )
replace IIINC48F = . if (IIINC48F >= 9 )
replace IRINC49F = . if (IRINC49F >= 999999 )
replace IIINC49F = . if (IIINC49F >= 9 )
replace IRINC48G = . if (IRINC48G >= 99 )
replace IIINC48G = . if (IIINC48G >= 9 )
replace IRINC49G = . if (IRINC49G >= 999999 )
replace IIINC49G = . if (IIINC49G >= 9 )
replace IRINC48H = . if (IRINC48H >= 99 )
replace IIINC48H = . if (IIINC48H >= 9 )
replace IRINC49H = . if (IRINC49H >= 999999 )
replace IRINC48I = . if (IRINC48I >= 99 )
replace IIINC48I = . if (IIINC48I >= 9 )
replace IRINC49I = . if (IRINC49I >= 999999 )
replace IIINC49I = . if (IIINC49I >= 9 )
replace IRALCRC = . if (IRALCRC >= 9 )
replace IRMJRC = . if (IRMJRC >= 9 )
replace IRCOCRC = . if (IRCOCRC >= 9 )
replace IRSEDRC = . if (IRSEDRC >= 9 )
replace IRTRNRC = . if (IRTRNRC >= 9 )
replace IRSTMRC = . if (IRSTMRC >= 9 )
replace IRANLRC = . if (IRANLRC >= 9 )
replace IRCIGRC = . if (IRCIGRC >= 9 )
replace IROTBRC = . if (IROTBRC >= 9 )
replace IRINHRC = . if (IRINHRC >= 9 )
replace IRCRKRC = . if (IRCRKRC >= 9 )
replace IRHALRC = . if (IRHALRC >= 9 )
replace IRHERRC = . if (IRHERRC >= 9 )
replace IRPCPRC = . if (IRPCPRC >= 9 )
replace IRICERC = . if (IRICERC >= 9 )
replace IRALCFQ = . if (IRALCFQ >= 9 )
replace IRMJFQ = . if (IRMJFQ >= 10 )
replace IRCOCFQ = . if (IRCOCFQ >= 9 )
replace IRSEDFQ = . if (IRSEDFQ >= 9 )
replace IRTRNFQ = . if (IRTRNFQ >= 9 )
replace IRSTMFQ = . if (IRSTMFQ >= 9 )
replace IRANLFQ = . if (IRANLFQ >= 9 )
replace IROTBFQ = . if (IROTBFQ >= 9 )
replace IRINHFQ = . if (IRINHFQ >= 9 )
replace IRHALFQ = . if (IRHALFQ >= 9 )
replace TOTINC = . if (TOTINC >= 9999999 )
replace TOTCAT = . if (TOTCAT >= 99 )
replace FAMINC = . if (FAMINC >= 6 )
replace PEREARN = . if (PEREARN >= 6 )
replace NEEDLREC = . if (NEEDLREC >= 91 )
replace NDL90REC = . if (NDL90REC >= 91 )
replace NDL90RC2 = . if (NDL90RC2 >= 81 )
replace IRDEP = . if (IRDEP >= 99 )
replace IRDEP1 = . if (IRDEP1 >= 998 )
replace IRDEP2 = . if (IRDEP2 >= 999 )
replace IRDEP3 = . if (IRDEP3 >= 999 )
replace IRDEP4 = . if (IRDEP4 >= 999 )
replace IRARG = . if (IRARG >= 99 )
replace IRARG1 = . if (IRARG1 >= 998 )
replace IRARG2 = . if (IRARG2 >= 999 )
replace IRARG3 = . if (IRARG3 >= 999 )
replace IRALN = . if (IRALN >= 99 )
replace IRALN1 = . if (IRALN1 >= 998 )
replace IRALN2 = . if (IRALN2 >= 999 )
replace IRALN3 = . if (IRALN3 >= 999 )
replace IRANX = . if (IRANX >= 99 )
replace IRANX1 = . if (IRANX1 >= 998 )
replace IRANX2 = . if (IRANX2 >= 999 )
replace IRANX3 = . if (IRANX3 >= 999 )
replace IRHLT = . if (IRHLT >= 99 )
replace IRHLT1 = . if (IRHLT1 >= 998 )
replace IRHLT2 = . if (IRHLT2 >= 999 )
replace IRHLT3 = . if (IRHLT3 >= 999 )
replace IRNTK = . if (IRNTK >= 99 )
replace IRNTK1 = . if (IRNTK1 >= 998 )
replace IRNTK2 = . if (IRNTK2 >= 999 )
replace IRNTK3 = . if (IRNTK3 >= 999 )
replace IRNTK4 = . if (IRNTK4 >= 999 )
replace IRUPS = . if (IRUPS >= 99 )
replace IRUPS1 = . if (IRUPS1 >= 998 )
replace IRUPS2 = . if (IRUPS2 >= 999 )
replace IRUPS3 = . if (IRUPS3 >= 999 )
replace IRLSW = . if (IRLSW >= 99 )
replace IRLSW1 = . if (IRLSW1 >= 998 )
replace IRLSW2 = . if (IRLSW2 >= 999 )
replace IRLSW3 = . if (IRLSW3 >= 999 )
replace IRSSP = . if (IRSSP >= 99 )
replace IRSSP1 = . if (IRSSP1 >= 998 )
replace IRSSP2 = . if (IRSSP2 >= 999 )
replace IRSSP3 = . if (IRSSP3 >= 999 )
replace IRCPE = . if (IRCPE >= 99 )
replace IRCPE1 = . if (IRCPE1 >= 998 )
replace IRCPE2 = . if (IRCPE2 >= 999 )
replace IRCPE3 = . if (IRCPE3 >= 999 )
replace IREMG = . if (IREMG >= 99 )
replace IREMG1 = . if (IREMG1 >= 998 )
replace IREMG2 = . if (IREMG2 >= 999 )
replace IREMG3 = . if (IREMG3 >= 999 )
replace IREMG4 = . if (IREMG4 >= 999 )
replace IRCDALC = . if (IRCDALC >= 13 )
replace IRCDCIG = . if (IRCDCIG >= 13 )
replace IRCDCOC = . if (IRCDCOC >= 13 )
replace IRCDMJ = . if (IRCDMJ >= 13 )
replace IREFALC = . if (IREFALC >= 13 )
replace IREFCIG = . if (IREFCIG >= 13 )
replace IREFCOC = . if (IREFCOC >= 13 )
replace IREFMJ = . if (IREFMJ >= 13 )
replace IRUDALC = . if (IRUDALC >= 13 )
replace IRUDCIG = . if (IRUDCIG >= 13 )
replace IRUDCOC = . if (IRUDCOC >= 13 )
replace IRUDMJ = . if (IRUDMJ >= 13 )
replace IRDPALC = . if (IRDPALC >= 13 )
replace IRDPCIG = . if (IRDPCIG >= 13 )
replace IRDPCOC = . if (IRDPCOC >= 13 )
replace IRDPMJ = . if (IRDPMJ >= 13 )
replace IRWSALC = . if (IRWSALC >= 13 )
replace IRWSCIG = . if (IRWSCIG >= 13 )
replace IRWSCOC = . if (IRWSCOC >= 13 )
replace IRWSMJ = . if (IRWSMJ >= 13 )
replace IRALCABS = . if (IRALCABS >= 13 )
replace IRALCAGG = . if (IRALCAGG >= 99 )
replace IRALCALO = . if (IRALCALO >= 99 )
replace IRALCARG = . if (IRALCARG >= 99 )
replace IRALCBRK = . if (IRALCBRK >= 99 )
replace IRALCDRU = . if (IRALCDRU >= 99 )
replace IRALCFRD = . if (IRALCFRD >= 99 )
replace IRALCHIG = . if (IRALCHIG >= 99 )
replace IRALCHOL = . if (IRALCHOL >= 99 )
replace IRALCINT = . if (IRALCINT >= 99 )
replace IRALCJOB = . if (IRALCJOB >= 99 )
replace IRALCMAT = . if (IRALCMAT >= 99 )
replace IRALCMOR = . if (IRALCMOR >= 99 )
replace IRALCQUI = . if (IRALCQUI >= 99 )
replace IRALCREL = . if (IRALCREL >= 99 )
replace IRALCREM = . if (IRALCREM >= 99 )
replace IRALCSHO = . if (IRALCSHO >= 99 )
replace IRALCTOS = . if (IRALCTOS >= 99 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

